@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae.cpp,v 1.104.2.2 2009/04/27 14:38:09 cvs Exp $
+//      $Id: cae.cpp,v 1.115.4.1 2012/08/03 16:52:38 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,13 +34,8 @@
 #include <string.h>
 #include <math.h>
 #include <ctype.h>
-#include <sys/ipc.h>
-#include <sys/shm.h>
 #include <errno.h>
-
-#ifdef SRC
-#include <samplerate.h>
-#endif
+#include <dlfcn.h>
 
 #include <qdir.h>
 #include <qsqldatabase.h>
@@ -51,19 +46,18 @@
 #include <rdcheck_daemons.h>
 #include <rddebug.h>
 #include <rdcmd_switch.h>
+#include <rdsystem.h>
 
 #include <cae_socket.h>
 #include <cae.h>
 
-
-struct RDMeterBlock *meter_block=NULL;
-int meter_block_id=-1;
 volatile bool exiting=false;
 RDConfig *rd_config;
 #ifdef JACK
 extern jack_client_t *jack_client;
 #endif  // JACK
 
+#define PRINT_COMMANDS
 
 void LogLine(RDConfig::LogPriority prio,const QString &line)
 {
@@ -101,7 +95,6 @@ void SigHandler(int signum)
       case SIGINT:
       case SIGTERM:
       case SIGHUP:
-        shmctl(meter_block_id,IPC_RMID,NULL);
 	exiting=true;
 	break;
   }
@@ -111,8 +104,6 @@ void SigHandler(int signum)
 MainObject::MainObject(QObject *parent,const char *name)
   :QObject(parent,name)
 {
-  struct shmid_ds shmid_ds;
-
   //
   // Read Command Options
   //
@@ -139,6 +130,8 @@ MainObject::MainObject(QObject *parent,const char *name)
   // Initialize Data Structures
   //
   debug=false;
+  twolame_handle=NULL;
+  mad_handle=NULL;
   if(qApp->argc()>1) {
     for(int i=1;i<qApp->argc();i++) {
       if(!strcmp(qApp->argv()[i],"-d")) {
@@ -154,6 +147,7 @@ MainObject::MainObject(QObject *parent,const char *name)
   next_play_handle=0;
   for(int i=0;i<CAE_MAX_CONNECTIONS;i++) {
     socket[i]=NULL;
+    meter_port[i]=0;
     istate[i]=0;
     argnum[i]=0;
     argptr[i]=0;
@@ -169,12 +163,17 @@ MainObject::MainObject(QObject *parent,const char *name)
       play_length[i][j]=0;
       play_speed[i][j]=100;
       play_pitch[i][j]=false;
+      for(int k=0;k<RD_MAX_PORTS;k++) {
+	output_status_flag[i][k][j]=false;
+      }
+#ifdef HAVE_TWOLAME
+      twolame_lameopts[i][j]=NULL;
+#endif  // HAVE_TWOLAME
+#ifdef HAVE_MAD
+      mad_active[i][j]=false;
+#endif  // HAVE_MAD
     }
   }
-  resample_buffer[0]=new float[RINGBUFFER_SIZE];
-  resample_buffer[1]=new float[2*RINGBUFFER_SIZE];
-  short_resample_buffer[0]=new float[RINGBUFFER_SIZE];
-  short_resample_buffer[1]=new float[2*RINGBUFFER_SIZE];
 #ifdef JACK
   jack_client=NULL;
 #endif  // JACK
@@ -201,50 +200,9 @@ MainObject::MainObject(QObject *parent,const char *name)
   }
 
   //
-  // Allocate the meter block sysv shared memory segment
+  // Allowcate Meter Socket
   //
-  // NOTE: To ensure that this segment gets destroyed upon program exit, we check
-  // to destroy it multiple ways to catch as many program exits possible: 
-  //  - upon receiving a signal (SIGHUP, SIGINT, SIGTERM)
-  //  - when the QApplication calls the commidData() method
-  //  - on return of the QApplication exec() method
-  //
-
-  // First try to create a new shared memory segment.
-  if((meter_block_id=
-      shmget(RD_METER_SHM_KEY,sizeof(struct RDMeterBlock),
-	     IPC_CREAT|IPC_EXCL|S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH))<0) {
-    if(errno!=EEXIST) {
-      LogLine(RDConfig::LogWarning,QString().
-	      sprintf("can't allocate shared memory segment, error:%d",
-		      errno));
-      exit(1);
-    }
-    // The shmget() error was due to an existing segment, so try to get it, release it, and re-get it.
-    meter_block_id = shmget(RD_METER_SHM_KEY,sizeof(struct RDMeterBlock),0);
-    shmctl(meter_block_id,IPC_RMID,NULL);
-    if((meter_block_id=shmget(RD_METER_SHM_KEY,sizeof(struct RDMeterBlock),
-			      IPC_CREAT|IPC_EXCL|S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH))<0) {
-      LogLine(RDConfig::LogErr,QString().sprintf("can't allocate shared memory segment after trying to destroy, error:%d",
-			      errno));
-      exit(1);
-    }
-  }
-  shmctl(meter_block_id,IPC_STAT,&shmid_ds);
-  shmid_ds.shm_perm.uid=rd_config->uid();
-  shmctl(meter_block_id,IPC_SET,&shmid_ds);
-  meter_block=(RDMeterBlock *)shmat(meter_block_id,NULL,0);
-  for(int i=0;i<RD_MAX_CARDS;i++) {
-    for(int j=0;j<RD_MAX_PORTS;j++) {
-      for(int k=0;k<2;k++) {
-	meter_block->input_meter[i][j][k]=-10000;
-	meter_block->output_meter[i][j][k]=-10000;
-      }
-      for(int k=0;k<RD_MAX_STREAMS;k++) {
-	meter_block->output_state[i][j][k]=false;
-      }
-    }
-  }
+  meter_socket=new QSocketDevice(QSocketDevice::Datagram);
 
   //
   // Open Database
@@ -270,6 +228,9 @@ MainObject::MainObject(QObject *parent,const char *name)
   // Start Up the Drivers
   //
   RDStation *station=new RDStation(rd_config->stationName());
+  RDSystem *sys=new RDSystem();
+  system_sample_rate=sys->sampleRate();
+  delete sys;
   hpiInit(station);
   alsaInit(station);
   jackInit(station);
@@ -493,15 +454,12 @@ void MainObject::stateRecordUpdate(int card,int stream,int state)
 void MainObject::updateMeters()
 {
   short levels[2];
+  unsigned positions[RD_MAX_STREAMS];
 
   if(exiting) {
     jackFree();
     alsaFree();
     hpiFree();
-    if(meter_block!=NULL) {
-      shmdt(meter_block);
-      shmctl(meter_block_id,IPC_RMID,NULL);
-    }
     RDDeletePid(RD_PID_DIR,"caed.pid");
     LogLine(RDConfig::LogInfo,"cae exiting");
     exit(0);
@@ -524,15 +482,14 @@ void MainObject::updateMeters()
 	      }
 	    }
 	    if(hpiGetInputMeters(i,j,levels)) {
-	      meter_block->input_meter[i][j][0]=levels[0];
-	      meter_block->input_meter[i][j][1]=levels[1];
+	      SendMeterLevelUpdate("I",i,j,levels);
 	    }
 	    if(hpiGetOutputMeters(i,j,levels)) {
-	      meter_block->output_meter[i][j][0]=levels[0];
-	      meter_block->output_meter[i][j][1]=levels[1];
+	      SendMeterLevelUpdate("O",i,j,levels);
 	    }      
 	  }
-	  hpiGetOutputPosition(i,meter_block->output_position[i]);
+	  hpiGetOutputPosition(i,positions);
+	  SendMeterPositionUpdate(i,positions);
 	  break;
 
 	case RDStation::Jack:
@@ -543,15 +500,14 @@ void MainObject::updateMeters()
 						 port_status[i][j]));
 	    }
 	    if(jackGetInputMeters(i,j,levels)) {
-	      meter_block->input_meter[i][j][0]=levels[0];
-	      meter_block->input_meter[i][j][1]=levels[1];
+	      SendMeterLevelUpdate("I",i,j,levels);
 	    }
 	    if(jackGetOutputMeters(i,j,levels)) {
-	      meter_block->output_meter[i][j][0]=levels[0];
-	      meter_block->output_meter[i][j][1]=levels[1];
+	      SendMeterLevelUpdate("O",i,j,levels);
 	    }
 	  }
-	  jackGetOutputPosition(i,meter_block->output_position[i]);
+	  jackGetOutputPosition(i,positions);
+	  SendMeterPositionUpdate(i,positions);
 	  break;
 
 	case RDStation::Alsa:
@@ -562,21 +518,22 @@ void MainObject::updateMeters()
 						 port_status[i][j]));
 	    }
 	    if(alsaGetInputMeters(i,j,levels)) {
-	      meter_block->input_meter[i][j][0]=levels[0];
-	      meter_block->input_meter[i][j][1]=levels[1];
+	      SendMeterLevelUpdate("I",i,j,levels);
 	    }
 	    if(alsaGetOutputMeters(i,j,levels)) {
-	      meter_block->output_meter[i][j][0]=levels[0];
-	      meter_block->output_meter[i][j][1]=levels[1];
+	      SendMeterLevelUpdate("O",i,j,levels);
 	    }
 	  }
-	  alsaGetOutputPosition(i,meter_block->output_position[i]);
+	  alsaGetOutputPosition(i,positions);
+	  SendMeterPositionUpdate(i,positions);
 	  break;
 
 	case RDStation::None:
 	  break;
     }
+    //
   }
+  //  SendMeterOutputStatusUpdate();
 }
 
 
@@ -682,6 +639,8 @@ void MainObject::DispatchCommand(int ch)
   QString wavename;
   char temp[256];
   int handle;
+  QString in_jport;
+  QString out_jport;
 
 #ifdef PRINT_COMMANDS
   printf("CAE: connection %d receiving ",ch);
@@ -1099,6 +1058,7 @@ void MainObject::DispatchCommand(int ch)
       }
       wavename = rd_config->audioFileName(QString(args[ch][7]));
       unlink(wavename);  // So we don't trainwreck any current playouts!
+      unlink(wavename+".energy");
       switch(cae_driver[card]) {
 	  case RDStation::Hpi:
 	    if(!hpiLoadRecord(card,stream,coding,channels,sample_rate,bit_rate,
@@ -1147,23 +1107,24 @@ void MainObject::DispatchCommand(int ch)
       return;
     }
     if((record_owner[card][stream]==-1)||(record_owner[card][stream]==ch)) {
+      unsigned len=0;
       switch(cae_driver[card]) {
 	  case RDStation::Hpi:
-	    if(!hpiUnloadRecord(card,stream)) {
+	    if(!hpiUnloadRecord(card,stream,&len)) {
 	      EchoArgs(ch,'-');
 	      return;
 	    }
 	    break;
 
 	  case RDStation::Alsa:
-	    if(!alsaUnloadRecord(card,stream)) {
+	    if(!alsaUnloadRecord(card,stream,&len)) {
 	      EchoArgs(ch,'-');
 	      return;
 	    }
 	    break;
 
 	  case RDStation::Jack:
-	    if(!jackUnloadRecord(card,stream)) {
+	    if(!jackUnloadRecord(card,stream,&len)) {
 	      EchoArgs(ch,'-');
 	      return;
 	    }
@@ -1175,9 +1136,11 @@ void MainObject::DispatchCommand(int ch)
       }
       record_owner[card][stream]=-1;
       LogLine(RDConfig::LogInfo,QString().
-	      sprintf("UnloadRecord - Card: %d  Stream: %d",
-		      card,stream));
-      EchoArgs(ch,'+');
+	      sprintf("UnloadRecord - Card: %d  Stream: %d, Length: %u",
+		      card,stream,len));
+      EchoCommand(ch,(const char *)QString().sprintf("UR %d %d %u +!",
+						     card,stream,
+	  (unsigned)((double)len*1000.0/(double)system_sample_rate)));
       return;
     }
     else {
@@ -1279,6 +1242,30 @@ void MainObject::DispatchCommand(int ch)
     return;
   }
 
+  if(!strcmp(args[ch][0],"CS")) {  // Set Clock Source
+    if((card<0)||(stream<0)) {
+      EchoArgs(ch,'-');
+      return;
+    }
+    switch(cae_driver[card]) {
+	case RDStation::Hpi:
+	  if(!hpiSetClockSource(card,stream)) {
+	    EchoArgs(ch,'-');
+	    return;
+	  }
+
+	default:
+	  EchoArgs(ch,'+');
+	  return;
+    }
+    if(rd_config->enableMixerLogging()) {
+      LogLine(RDConfig::LogInfo,QString().
+	      sprintf("SetClockSource - Card: %d  Source: %d",card,stream));
+    }
+    EchoArgs(ch,'+');
+    return;
+  }
+
   if(!strcmp(args[ch][0],"IV")) {  // Set Input Volume
     if((card<0)||(stream<0)) {
       EchoArgs(ch,'-');
@@ -1710,6 +1697,80 @@ void MainObject::DispatchCommand(int ch)
     }
     return;
   }
+
+  if(!strcmp(args[ch][0],"ME")) {  // Meter Enable
+    sscanf(args[ch][1],"%d",&port);
+    if((port<0)||(port>0xFFFF)) {
+      EchoArgs(ch,'-');
+      return;
+    }
+    meter_port[ch]=port;
+    EchoArgs(ch,'+');
+    SendMeterOutputStatusUpdate();
+    return;
+  }
+
+  if(!strcmp(args[ch][0],"OS")) {  // Set Output Status Flag
+    sscanf(args[ch][1],"%d",&card);
+    sscanf(args[ch][2],"%d",&port);
+    sscanf(args[ch][3],"%d",&stream);
+    if((card<0)||(card>=RD_MAX_CARDS)||
+       (port<0)||(port>=RD_MAX_PORTS)||
+       (stream<0)||(stream>=RD_MAX_STREAMS)) {
+      EchoArgs(ch,'-');
+      return;
+    }
+    output_status_flag[card][port][stream]=args[ch][4][0]=='1';
+    SendMeterOutputStatusUpdate(card,port,stream);
+    EchoArgs(ch,'+');
+    return;
+  }
+
+  if(!strcmp(args[ch][0],"JC")) {  // Connect JACK Ports
+    pos=-1;
+    for(int i=0;i<argnum[ch];i++) {
+      if(args[ch][i][0]=='|') {
+	pos=i;
+      }
+    }
+    if(pos<0) {
+      return;
+    }
+    for(int i=1;i<pos;i++) {
+      out_jport+=args[ch][i];
+      out_jport+=" ";
+    }
+    out_jport=out_jport.left(out_jport.length()-1);
+    for(int i=pos+1;i<argnum[ch];i++) {
+      in_jport+=args[ch][i];
+      in_jport+=" ";
+    }
+    in_jport=in_jport.left(in_jport.length()-1);
+    jackConnectPorts(out_jport,in_jport);
+  }
+
+  if(!strcmp(args[ch][0],"JD")) {  // Disconnect JACK Ports
+    pos=-1;
+    for(int i=0;i<argnum[ch];i++) {
+      if(args[ch][i][0]=='|') {
+	pos=i;
+      }
+    }
+    if(pos<0) {
+      return;
+    }
+    for(int i=1;i<pos;i++) {
+      out_jport+=args[ch][i];
+      out_jport+=" ";
+    }
+    out_jport=out_jport.left(out_jport.length()-1);
+    for(int i=pos+1;i<argnum[ch];i++) {
+      in_jport+=args[ch][i];
+      in_jport+=" ";
+    }
+    in_jport=in_jport.left(in_jport.length()-1);
+    jackDisconnectPorts(out_jport,in_jport);
+  }
 }
 
 
@@ -1719,20 +1780,22 @@ void MainObject::KillSocket(int ch)
   argnum[ch]=0;
   argptr[ch]=0;
   auth[ch]=false;
+  meter_port[ch]=0;
   for(int i=0;i<RD_MAX_CARDS;i++) {
     for(int j=0;j<RD_MAX_STREAMS;j++) {
       if(record_owner[i][j]==ch) {
+	unsigned len=0;
 	switch(cae_driver[i]) {
 	    case RDStation::Hpi:
-	      hpiUnloadRecord(i,j);
+	      hpiUnloadRecord(i,j,&len);
 	      break;
 
 	    case RDStation::Jack:
-	      jackUnloadRecord(i,j);
+	      jackUnloadRecord(i,j,&len);
 	      break;
 
 	    case RDStation::Alsa:
-	      alsaUnloadRecord(i,j);
+	      alsaUnloadRecord(i,j,&len);
 	      break;
 
 	    default:
@@ -1888,87 +1951,37 @@ int MainObject::GetHandle(int card,int stream)
 }
 
 
-long MainObject::Resample(short *data_in,short *data_out,long frames,
-			  double ratio,int chans)
-{
-#ifdef SRC
-#ifdef HAVE_SRC_CONV
-  src_short_to_float_array(data_in,short_resample_buffer[0],frames*chans);
-#else
-  for(int i=0;i<(frames*chans);i++) {
-    short_resample_buffer[0][i]=((float)(data_in[i]))/32768.0;
-  }
-#endif  // HAVE_SRC_CONV
-  long n=Resample(short_resample_buffer[0],short_resample_buffer[1],frames,
-		  ratio,chans);
-#ifdef HAVE_SRC_CONV
-  src_float_to_short_array(short_resample_buffer[1],data_out,n*chans);
-#else
-  for(int i=0;i<(n*chans);i++) {
-    data_out[i]=(short)(short_resample_buffer[1][i]*32768.0);
-  }
-#endif  // HAVE_SRC_CONV
-  return n;
-#else
-  for(int i=0;i<(frames*chans);i++) {
-    data_out[i]=data_in[i];
-  }
-  return frames;
-#endif  // SRC
-}
-
-
-long MainObject::Resample(float *data_in,float *data_out,long frames,
-			  double ratio,int chans)
-{
-#ifdef SRC
-  int err;
-
-  SRC_DATA src_data;
-
-  src_data.data_in=resample_buffer[0];
-  src_data.data_out=resample_buffer[1];
-  src_data.input_frames=frames;
-  src_data.output_frames=2*RINGBUFFER_SIZE;
-  src_data.src_ratio=ratio;
-  for(int i=0;i<chans;i++) {
-    for(int j=0;j<frames;j++) {
-      resample_buffer[0][j]=data_in[j*chans+i];
-    }
-    if((err=src_simple(&src_data,SRC_SINC_MEDIUM_QUALITY,1))!=0) {
-      LogLine(RDConfig::LogErr,QString().
-	      sprintf("SRC Error: %s",src_strerror(err)));
-    }
-    for(int j=0;j<src_data.output_frames_gen;j++) {
-      data_out[j*chans+i]=resample_buffer[1][j];
-    }
-  }
-  return src_data.output_frames_gen;
-#else
-  for(int i=0;i<(frames*chans);i++) {
-    data_out[i]=data_in[i];
-  }
-  return frames;
-#endif  // SRC
-}
-
-
 void MainObject::ProbeCaps(RDStation *station)
 {
-  station->
-    setHaveCapability(RDStation::HaveOggenc,!system("oggenc --version > /dev/null 2> /dev/null"));
-  station->
-    setHaveCapability(RDStation::HaveOgg123,!system("ogg123 --version > /dev/null 2> /dev/null"));
-  station->
-    setHaveCapability(RDStation::HaveFlac,!system("flac --version > /dev/null 2> /dev/null"));
-  station->
-    setHaveCapability(RDStation::HaveLame,!system("lame --version > /dev/null 2> /dev/null"));
-  station->
-    setHaveCapability(RDStation::HaveMpg321,!system("mpg321 --version > /dev/null 2> /dev/null"));
-#ifdef HPI
-  station->setDriverVersion(RDStation::Hpi,"Generic");
+  void *handle;
+
+  //
+  // Patent-clear codecs
+  //
+#ifdef HAVE_VORBIS
+  station->setHaveCapability(RDStation::HaveOggenc,true);
+  station->setHaveCapability(RDStation::HaveOgg123,true);
 #else
-  station->setDriverVersion(RDStation::Hpi,"");
+  station->setHaveCapability(RDStation::HaveOggenc,false);
+  station->setHaveCapability(RDStation::HaveOgg123,false);
+#endif  // HAVE_VORBIS
+#ifdef HAVE_FLAC
+  station->setHaveCapability(RDStation::HaveFlac,true);
+#else
+  station->setHaveCapability(RDStation::HaveFlac,false);
+#endif  // HAVE_FLAC
+
+  //
+  // MPEG Codecs
+  //
+  station->setHaveCapability(RDStation::HaveLame,CheckLame());
+  station->setHaveCapability(RDStation::HaveTwoLame,LoadTwoLame());
+  station->setHaveCapability(RDStation::HaveMpg321,LoadMad());
+
+#ifdef HPI
+  station->setDriverVersion(RDStation::Hpi,hpiVersion());
+#else
+  station->setDriverVersion(RDStation::Hpi,"[not enabled]");
 #endif  // HPI
 #ifdef JACK
   //
@@ -2002,12 +2015,6 @@ void MainObject::ClearDriverEntries(RDStation *station)
   }
 }
 
-/* This is an overloaded virtual function that gets called on session end.  We use it to ensure shm is destroyed */
-void QApplication::commitData(QSessionManager &sm) {
-  LogLine(RDConfig::LogDebug,"cae commitData()");
-  shmctl(meter_block_id,IPC_RMID,NULL);
-  return;
-};
 
 /* This is an overloaded virtual function to tell a session manager not to restart this daemon. */
 void QApplication::saveState(QSessionManager &sm) {
@@ -2016,6 +2023,225 @@ void QApplication::saveState(QSessionManager &sm) {
   return;
 };
 
+
+bool MainObject::CheckLame()
+{
+#ifdef HAVE_LAME
+  return dlopen("libmp3lame.so",RTLD_LAZY)!=NULL;
+#else
+  return false;
+#endif  // HAVE_LAME
+}
+
+
+bool MainObject::LoadTwoLame()
+{
+#ifdef HAVE_TWOLAME
+  if((twolame_handle=dlopen("libtwolame.so",RTLD_NOW))==NULL) {
+    LogLine(RDConfig::LogInfo,
+	 "TwoLAME encoder library not found, MPEG L2 encoding not supported");
+    return false;
+  }
+  *(void **)(&twolame_init)=dlsym(twolame_handle,"twolame_init");
+  *(void **)(&twolame_set_mode)=dlsym(twolame_handle,"twolame_set_mode");
+  *(void **)(&twolame_set_num_channels)=
+    dlsym(twolame_handle,"twolame_set_num_channels");
+  *(void **)(&twolame_set_in_samplerate)=
+    dlsym(twolame_handle,"twolame_set_in_samplerate");
+  *(void **)(&twolame_set_out_samplerate)=
+    dlsym(twolame_handle,"twolame_set_out_samplerate");
+  *(void **)(&twolame_set_bitrate)=
+    dlsym(twolame_handle,"twolame_set_bitrate");
+  *(void **)(&twolame_init_params)=
+    dlsym(twolame_handle,"twolame_init_params");
+  *(void **)(&twolame_close)=dlsym(twolame_handle,"twolame_close");
+  *(void **)(&twolame_encode_buffer_interleaved)=
+    dlsym(twolame_handle,"twolame_encode_buffer_interleaved");
+  *(void **)(&twolame_encode_buffer_float32_interleaved)=
+    dlsym(twolame_handle,"twolame_encode_buffer_float32_interleaved");
+  *(void **)(&twolame_encode_flush)=
+    dlsym(twolame_handle,"twolame_encode_flush");
+  *(void **)(&twolame_set_energy_levels)=
+    dlsym(twolame_handle,"twolame_set_energy_levels");
+  LogLine(RDConfig::LogInfo,
+	  "Found TwoLAME encoder library, MPEG L2 encoding supported");
+  return true;
+#else
+  LogLine(RDConfig::LogInfo,"MPEG L2 encoding not enabled");
+  return false;
+#endif  // HAVE_TWOLAME
+}
+
+
+bool MainObject::InitTwoLameEncoder(int card,int stream,int chans,int samprate,
+				    int bitrate)
+{
+#ifdef HAVE_TWOLAME
+  TWOLAME_MPEG_mode mpeg_mode=TWOLAME_STEREO;
+
+  switch(chans) {
+  case 1:
+    mpeg_mode=TWOLAME_MONO;
+    break;
+
+  case 2:
+    mpeg_mode=TWOLAME_STEREO;    
+    break;
+  }
+  if((twolame_lameopts[card][stream]=twolame_init())==NULL) {
+    LogLine(RDConfig::LogErr,QString().sprintf("unable to initialize twolame instance, card=%d, stream=%d",card,stream));
+    return false;
+  }
+  twolame_set_mode(twolame_lameopts[card][stream],mpeg_mode);
+  twolame_set_num_channels(twolame_lameopts[card][stream],chans);
+  twolame_set_in_samplerate(twolame_lameopts[card][stream],samprate);
+  twolame_set_out_samplerate(twolame_lameopts[card][stream],samprate);
+  twolame_set_bitrate(twolame_lameopts[card][stream],bitrate/1000);
+  twolame_set_energy_levels(twolame_lameopts[card][stream],1);
+  if(twolame_init_params(twolame_lameopts[card][stream])!=0) {
+    LogLine(RDConfig::LogErr,QString().sprintf("invalid twolame parameters, card=%d, stream=%d, chans=%d, samprate=%d  bitrate=%d",
+					       card,stream,chans,samprate,bitrate));
+    return false;
+  }
+  return true;
+#else
+  return false;
+#endif  // HAVE_TWOLAME
+}
+
+
+void MainObject::FreeTwoLameEncoder(int card,int stream)
+{
+#ifdef HAVE_TWOLAME
+  if(twolame_lameopts[card][stream]!=NULL) { 
+    twolame_close(&twolame_lameopts[card][stream]);
+    twolame_lameopts[card][stream]=NULL;
+  }
+#endif  // HAVE_TWOLAME
+}
+
+
+bool MainObject::LoadMad()
+{
+#ifdef HAVE_MAD
+  if((mad_handle=dlopen("libmad.so",RTLD_NOW))==NULL) {
+    LogLine(RDConfig::LogInfo,
+	 "MAD decoder library not found, MPEG L2 decoding not supported");
+    return false;
+  }
+  *(void **)(&mad_stream_init)=
+    dlsym(mad_handle,"mad_stream_init");
+  *(void **)(&mad_frame_init)=
+    dlsym(mad_handle,"mad_frame_init");
+  *(void **)(&mad_synth_init)=
+    dlsym(mad_handle,"mad_synth_init");
+  *(void **)(&mad_stream_buffer)=
+    dlsym(mad_handle,"mad_stream_buffer");
+  *(void **)(&mad_frame_decode)=
+    dlsym(mad_handle,"mad_frame_decode");
+  *(void **)(&mad_synth_frame)=
+    dlsym(mad_handle,"mad_synth_frame");
+  *(void **)(&mad_frame_finish)=
+    dlsym(mad_handle,"mad_frame_finish");
+  *(void **)(&mad_stream_finish)=
+    dlsym(mad_handle,"mad_stream_finish");
+  LogLine(RDConfig::LogInfo,
+	  "Found MAD decoder library, MPEG L2 decoding supported");
+  return true;
+#else
+  LogLine(RDConfig::LogInfo,"MPEG L2 decoding not enabled");
+  return false;
+#endif  // HAVE_MAD
+}
+
+
+void MainObject::InitMadDecoder(int card,int stream,RDWaveFile *wave)
+{
+#ifdef HAVE_MAD
+  if(mad_active[card][stream]) {
+    FreeMadDecoder(card,stream);
+  }
+  mad_stream_init(&mad_stream[card][stream]);
+  mad_frame_init(&mad_frame[card][stream]);
+  mad_synth_init(&mad_synth[card][stream]);
+  mad_frame_size[card][stream]=
+    144*wave->getHeadBitRate()/wave->getSamplesPerSec();
+  mad_left_over[card][stream]=0;
+  mad_active[card][stream]=true;
+#endif  // HAVE_MAD
+}
+
+
+void MainObject::FreeMadDecoder(int card,int stream)
+{
+#ifdef HAVE_MAD
+  if(mad_active[card][stream]) {
+    mad_synth_finish(&mad_synth[card][stream]);
+    mad_frame_finish(&mad_frame[card][stream]);
+    mad_stream_finish(&mad_stream[card][stream]);
+    mad_frame_size[card][stream]=0;
+    mad_left_over[card][stream]=0;
+    mad_active[card][stream]=false;
+  }
+#endif  // HAVE_MAD
+}
+
+
+void MainObject::SendMeterLevelUpdate(const QString &type,int cardnum,
+				      int portnum,short levels[])
+{
+  char msg[1500];
+  int n=snprintf(msg,1500,"ML %s %d %d %d %d",
+		 (const char *)type,cardnum,portnum,levels[0],levels[1]);
+  SendMeterUpdate(msg,n);
+}
+
+
+void MainObject::SendMeterPositionUpdate(int cardnum,unsigned pos[])
+{
+  char msg[1500];
+  int n;
+  for(unsigned i=0;i<RD_MAX_STREAMS;i++) {
+    n=snprintf(msg,1500,"MP %d %d %d",cardnum,i,pos[i]);
+    SendMeterUpdate(msg,n);
+  }
+}
+
+
+void MainObject::SendMeterOutputStatusUpdate()
+{
+  for(unsigned i=0;i<RD_MAX_CARDS;i++) {
+    if(cae_driver[i]!=RDStation::None) {
+      for(unsigned j=0;j<RD_MAX_PORTS;j++) {
+	for(unsigned k=0;k<RD_MAX_STREAMS;k++) {
+	  SendMeterOutputStatusUpdate(i,j,k);
+	}
+      }
+    }
+  }
+}
+
+
+void MainObject::SendMeterOutputStatusUpdate(int card,int port,int stream)
+{
+  char msg[1500];
+  int n;
+  n=snprintf(msg,1500,"MS %d %d %d %d",card,port,stream,
+	     output_status_flag[card][port][stream]);
+  SendMeterUpdate(msg,n);
+}
+
+
+void MainObject::SendMeterUpdate(const char *msg,unsigned len)
+{
+  for(unsigned i=0;i<CAE_MAX_CONNECTIONS;i++) {
+    if(meter_port[i]>0) {
+      meter_socket->writeBlock(msg,len,socket[i]->peerAddress(),meter_port[i]);
+    }
+  }
+}
+
+
 int main(int argc,char *argv[])
 {
   int rc;
@@ -2023,6 +2249,5 @@ int main(int argc,char *argv[])
   new MainObject(NULL,"main");
   rc=a.exec();
   LogLine(RDConfig::LogDebug,QString().sprintf("cae post a.exec() rc:%d", rc));
-  shmctl(meter_block_id,IPC_RMID,NULL);
   return rc;
 }
