@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae_alsa.cpp,v 1.41.2.3 2010/01/23 02:53:52 cvs Exp $
+//      $Id: cae_alsa.cpp,v 1.48.6.1 2012/04/23 16:18:55 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -429,6 +429,10 @@ void AlsaPlay2Callback(struct alsa_format *alsa_format)
 	      alsa_output_pos[alsa_format->card][j]+=n;
 	      if((n==0)&&alsa_eof[alsa_format->card][j]) {
 		alsa_stopping[alsa_format->card][j]=true;
+		// Empty the ring buffer
+		while(alsa_play_ring[alsa_format->card][j]->
+		      read(alsa_buffer,alsa_format->buffer_size*2/
+			   alsa_format->periods)/(2*sizeof(short))>0);	       
 	      }
 	    }
 	  }
@@ -531,7 +535,7 @@ void *AlsaPlayCallback(void *ptr)
 void MainObject::AlsaInitCallback()
 {
   int avg_periods=
-    (330*rd_config->sampleRate())/(1000*rd_config->alsaPeriodSize());
+    (330*system_sample_rate)/(1000*rd_config->alsaPeriodSize());
   for(int i=0;i<RD_MAX_CARDS;i++) {
     for(int j=0;j<RD_MAX_PORTS;j++) {
       alsa_recording[i][j]=false;
@@ -631,6 +635,10 @@ void MainObject::alsaInit(RDStation *station)
   for(int i=0;i<RD_MAX_CARDS;i++) {
     for(int j=0;j<RD_MAX_STREAMS;j++) {
       alsa_input_volume_db[i][j]=0;
+      alsa_samples_recorded[i][j]=0;
+#ifdef HAVE_MAD
+      mad_mpeg[i][j]=new unsigned char[16384];
+#endif  // HAVE_MAD
       for(int k=0;k<RD_MAX_PORTS;k++) {
 	alsa_output_volume_db[i][k][j]=0;
       }
@@ -675,7 +683,7 @@ void MainObject::alsaInit(RDStation *station)
   //
   AlsaInitCallback();
   alsa_wave_buffer=new short[RINGBUFFER_SIZE];
-  alsa_resample_buffer=new short[2*RINGBUFFER_SIZE];
+  //alsa_resample_buffer=new short[2*RINGBUFFER_SIZE];
 
   //
   // Start Up Interfaces
@@ -761,7 +769,7 @@ void MainObject::alsaFree()
 bool MainObject::alsaLoadPlayback(int card,QString wavename,int *stream)
 {
 #ifdef ALSA
-  if(alsa_play_format[card].exiting || ((*stream=GetAlsaOutputStream(card))<0)) {
+  if(alsa_play_format[card].exiting||((*stream=GetAlsaOutputStream(card))<0)) {
     LogLine(RDConfig::LogErr,QString().sprintf(
             "Error: alsaLoadPlayback(%s) GetAlsaOutputStream():%d < 0",
             (const char *) wavename,
@@ -779,13 +787,21 @@ bool MainObject::alsaLoadPlayback(int card,QString wavename,int *stream)
     *stream=-1;
     return false;
   }
-  if((alsa_play_wave[card][*stream]->getFormatTag()!=WAVE_FORMAT_PCM)||
-     (alsa_play_wave[card][*stream]->getBitsPerSample()!=16)) {
+  switch(alsa_play_wave[card][*stream]->getFormatTag()) {
+  case WAVE_FORMAT_PCM:
+  case WAVE_FORMAT_VORBIS:
+    break;
+    
+  case WAVE_FORMAT_MPEG:
+    InitMadDecoder(card,*stream,alsa_play_wave[card][*stream]);
+    break;
+    
+  default:
     LogLine(RDConfig::LogErr,QString().sprintf(
-            "Error: alsaLoadPlayback(%s)   getFormatTag()%d || getBistsPerSample()%d failed",
-            (const char *) wavename,
-            alsa_play_wave[card][*stream]->getFormatTag(),
-            alsa_play_wave[card][*stream]->getBitsPerSample() ));
+	   "Error: alsaLoadPlayback(%s)   getFormatTag()%d || getBistsPerSample()%d failed",
+	   (const char *) wavename,
+	   alsa_play_wave[card][*stream]->getFormatTag(),
+	   alsa_play_wave[card][*stream]->getBitsPerSample() ));
     delete alsa_play_wave[card][*stream];
     alsa_play_wave[card][*stream]=NULL;
     FreeAlsaOutputStream(card,*stream);
@@ -798,6 +814,7 @@ bool MainObject::alsaLoadPlayback(int card,QString wavename,int *stream)
   alsa_offset[card][*stream]=0;
   alsa_output_pos[card][*stream]=0;
   alsa_eof[card][*stream]=false;
+  alsa_play_ring[card][*stream]->reset();
   FillAlsaOutputStream(card,*stream);
   return true;
 #else
@@ -813,6 +830,11 @@ bool MainObject::alsaUnloadPlayback(int card,int stream)
     return false;
   }
   alsa_playing[card][stream]=false;
+  switch(alsa_play_wave[card][stream]->getFormatTag()) {
+  case WAVE_FORMAT_MPEG:
+    FreeMadDecoder(card,stream);
+    break;
+  }
   alsa_play_wave[card][stream]->closeWave();
   delete alsa_play_wave[card][stream];
   alsa_play_wave[card][stream]=NULL;
@@ -827,24 +849,47 @@ bool MainObject::alsaUnloadPlayback(int card,int stream)
 bool MainObject::alsaPlaybackPosition(int card,int stream,unsigned pos)
 {
 #ifdef ALSA
+  unsigned offset=0;
+
   if(alsa_play_format[card].exiting){
     return false;
   }
-  alsa_play_ring[card][stream]->reset();
-  unsigned offset=
-    (unsigned)((double)alsa_play_wave[card][stream]->getSamplesPerSec()*
-	       (double)alsa_play_wave[card][stream]->getBlockAlign()*
-	       (double)pos/1000);
-  alsa_offset[card][stream]=
-    offset/alsa_play_wave[card][stream]->getBlockAlign();
-  offset=
-    alsa_offset[card][stream]*alsa_play_wave[card][stream]->getBlockAlign();
-  if(alsa_offset[card][stream]>(int)alsa_play_wave[card][stream]->getSampleLength()) {
+  switch(alsa_play_wave[card][stream]->getFormatTag()) {
+  case WAVE_FORMAT_PCM:
+    offset=(unsigned)((double)alsa_play_wave[card][stream]->getSamplesPerSec()*
+		      (double)alsa_play_wave[card][stream]->getBlockAlign()*
+		      (double)pos/1000);
+    alsa_offset[card][stream]=
+      offset/alsa_play_wave[card][stream]->getBlockAlign();
+    offset=
+      alsa_offset[card][stream]*alsa_play_wave[card][stream]->getBlockAlign();
+    break;
+
+  case WAVE_FORMAT_MPEG:
+    offset=(unsigned)((double)alsa_play_wave[card][stream]->getSamplesPerSec()*
+		      (double)pos/1000);
+    alsa_offset[card][stream]=offset/1152*1152;
+    offset=alsa_offset[card][stream]/1152*
+      alsa_play_wave[card][stream]->getBlockAlign();
+    FreeMadDecoder(card,stream);
+    InitMadDecoder(card,stream,alsa_play_wave[card][stream]);
+    break;
+  }
+  if(alsa_offset[card][stream]>
+     (int)alsa_play_wave[card][stream]->getSampleLength()) {
     return false;
   }
   alsa_output_pos[card][stream]=0;
   alsa_play_wave[card][stream]->seekWave(offset,SEEK_SET);
+  alsa_eof[card][stream]=false;
+  alsa_play_ring[card][stream]->reset();
   FillAlsaOutputStream(card,stream);
+
+  if(alsa_playing[card][stream]) {
+    alsa_stop_timer[card][stream]->stop();
+    alsa_stop_timer[card][stream]->
+      start(alsa_play_wave[card][stream]->getExtTimeLength()-pos,true);
+  }
   return true;
 #else
   return false;
@@ -889,6 +934,7 @@ bool MainObject::alsaStopPlayback(int card,int stream)
     return false;
   }
   alsa_playing[card][stream]=false;
+  alsa_play_ring[card][stream]->reset();
   alsa_stop_timer[card][stream]->stop();
   statePlayUpdate(card,stream,2);
   return true;
@@ -903,10 +949,70 @@ bool MainObject::alsaLoadRecord(int card,int stream,int coding,int chans,
 {
 #ifdef ALSA
   alsa_record_wave[card][stream]=new RDWaveFile(wavename);
-  alsa_record_wave[card][stream]->setFormatTag(WAVE_FORMAT_PCM);
-  alsa_record_wave[card][stream]->setChannels(chans);
-  alsa_record_wave[card][stream]->setSamplesPerSec(samprate);
-  alsa_record_wave[card][stream]->setBitsPerSample(16);
+  switch(coding) {
+  case 0:  // PCM16
+    alsa_record_wave[card][stream]->setFormatTag(WAVE_FORMAT_PCM);
+    alsa_record_wave[card][stream]->setChannels(chans);
+    alsa_record_wave[card][stream]->setSamplesPerSec(samprate);
+    alsa_record_wave[card][stream]->setBitsPerSample(16);
+    break;
+
+  case 2:  // MPEG Layer 2
+    if(!InitTwoLameEncoder(card,stream,chans,samprate,bitrate)) {
+      delete alsa_record_wave[card][stream];
+      alsa_record_wave[card][stream]=NULL;
+      return false;
+    }
+    alsa_record_wave[card][stream]->setFormatTag(WAVE_FORMAT_MPEG);
+    alsa_record_wave[card][stream]->setChannels(chans);
+    alsa_record_wave[card][stream]->setSamplesPerSec(samprate);
+    alsa_record_wave[card][stream]->setBitsPerSample(16);
+    alsa_record_wave[card][stream]->setHeadLayer(ACM_MPEG_LAYER2);
+    switch(chans) {
+    case 1:
+      alsa_record_wave[card][stream]->setHeadMode(ACM_MPEG_SINGLECHANNEL);
+      break;
+
+    case 2:
+      alsa_record_wave[card][stream]->setHeadMode(ACM_MPEG_STEREO);
+      break;
+
+    default:
+      LogLine(RDConfig::LogErr,QString().
+	sprintf("requested unsupported channel count %d, card: %d, stream: %d",
+		chans,card,stream));
+      delete alsa_record_wave[card][stream];
+      alsa_record_wave[card][stream]=NULL;
+      return false;
+    }
+    alsa_record_wave[card][stream]->setHeadBitRate(bitrate);
+    alsa_record_wave[card][stream]->setMextChunk(true);
+    alsa_record_wave[card][stream]->setMextHomogenous(true);
+    alsa_record_wave[card][stream]->setMextPaddingUsed(false);
+    alsa_record_wave[card][stream]->setMextHackedBitRate(true);
+    alsa_record_wave[card][stream]->setMextFreeFormat(false);
+    alsa_record_wave[card][stream]->
+      setMextFrameSize(144*alsa_record_wave[card][stream]->getHeadBitRate()/
+		       alsa_record_wave[card][stream]->getSamplesPerSec());
+    alsa_record_wave[card][stream]->setMextAncillaryLength(5);
+    alsa_record_wave[card][stream]->setMextLeftEnergyPresent(true);
+    if(chans>1) {
+      alsa_record_wave[card][stream]->setMextRightEnergyPresent(true);
+    }
+    else {
+      alsa_record_wave[card][stream]->setMextRightEnergyPresent(false);
+    }
+    alsa_record_wave[card][stream]->setMextPrivateDataPresent(false);
+    break;
+
+  default:
+    LogLine(RDConfig::LogErr,QString().
+	    sprintf("requested invalid audio encoding %d, card: %d, stream: %d",
+		    coding,card,stream));
+    delete alsa_record_wave[card][stream];
+    alsa_record_wave[card][stream]=NULL;
+    return false;
+  }
   alsa_record_wave[card][stream]->setBextChunk(true);
   alsa_record_wave[card][stream]->setLevlChunk(true);
   if(!alsa_record_wave[card][stream]->createWave()) {
@@ -926,17 +1032,20 @@ bool MainObject::alsaLoadRecord(int card,int stream,int coding,int chans,
 }
 
 
-bool MainObject::alsaUnloadRecord(int card,int stream)
+bool MainObject::alsaUnloadRecord(int card,int stream,unsigned *len)
 {
 #ifdef ALSA
   alsa_recording[card][stream]=false;
   alsa_ready[card][stream]=false;
   EmptyAlsaInputStream(card,stream);
-  alsa_record_wave[card][stream]->closeWave();
+  *len=alsa_samples_recorded[card][stream];
+  alsa_samples_recorded[card][stream]=0;
+  alsa_record_wave[card][stream]->closeWave(*len);
   delete alsa_record_wave[card][stream];
   alsa_record_wave[card][stream]=NULL;
   delete alsa_record_ring[card][stream];
   alsa_record_ring[card][stream]=NULL;
+  FreeTwoLameEncoder(card,stream);
   return true;
 #else
   return false;
@@ -1165,11 +1274,13 @@ void MainObject::alsaGetOutputPosition(int card,unsigned *pos)
 {// pos is in miliseconds
 #ifdef ALSA
   for(int i=0;i<RD_MAX_STREAMS;i++) {
-    if (!alsa_play_format[card].exiting){
-      pos[i]=((unsigned long long)(alsa_offset[card][i]+
-				    alsa_output_pos[card][i]));
-    } else {
-      pos = 0;
+    if((!alsa_play_format[card].exiting)&&(alsa_play_wave[card][i]!=NULL)) {
+      pos[i]=1000*(unsigned long long)(alsa_offset[card][i]+
+				       alsa_output_pos[card][i])/
+	alsa_play_wave[card][i]->getSamplesPerSec();
+    } 
+    else {
+      pos[i]=0;
     }
   }
 #endif  // ALSA
@@ -1255,12 +1366,16 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
     sr=alsa_play_format[card].sample_rate;
   }
   else {
-    sr=rd_config->sampleRate();
+    sr=system_sample_rate;
   }
   snd_pcm_hw_params_set_rate_near(pcm,hwparams,&sr,&dir);
-  if((sr>(rd_config->sampleRate()-RD_ALSA_SAMPLE_RATE_TOLERANCE))&&
-     (sr<(rd_config->sampleRate()+RD_ALSA_SAMPLE_RATE_TOLERANCE))) {
-    sr=rd_config->sampleRate();
+  if((sr<(system_sample_rate-RD_ALSA_SAMPLE_RATE_TOLERANCE))||
+     (sr>(system_sample_rate+RD_ALSA_SAMPLE_RATE_TOLERANCE))) {
+    LogLine(RDConfig::LogErr,
+	    QString().sprintf("  Asked for sample rate %u, got %u",
+			      system_sample_rate,sr));
+    LogLine(RDConfig::LogErr,"  Sample rate unsupported by device");
+    return false;
   }
   alsa_capture_format[card].sample_rate=sr;
   LogLine(RDConfig::LogNotice,QString().sprintf("  SampleRate = %u",sr));
@@ -1404,11 +1519,15 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
   //
   // Sample Rate
   //
-  sr=rd_config->sampleRate();
+  sr=system_sample_rate;
   snd_pcm_hw_params_set_rate_near(pcm,hwparams,&sr,&dir);
-  if((sr>(rd_config->sampleRate()-RD_ALSA_SAMPLE_RATE_TOLERANCE))&&
-     (sr<(rd_config->sampleRate()+RD_ALSA_SAMPLE_RATE_TOLERANCE))) {
-    sr=rd_config->sampleRate();
+  if((sr<(system_sample_rate-RD_ALSA_SAMPLE_RATE_TOLERANCE))||
+     (sr>(system_sample_rate+RD_ALSA_SAMPLE_RATE_TOLERANCE))) {
+    LogLine(RDConfig::LogErr,
+	    QString().sprintf("  Asked for sample rate %u, got %u",
+			      system_sample_rate,sr));
+    LogLine(RDConfig::LogErr,"  Sample rate unsupported by device");
+    return false;
   }
   alsa_play_format[card].sample_rate=sr;
   LogLine(RDConfig::LogDebug,QString().sprintf("  SampleRate = %u",sr));
@@ -1522,48 +1641,138 @@ void MainObject::EmptyAlsaInputStream(int card,int stream)
   unsigned n=alsa_record_ring[card][stream]->
     read((char *)alsa_wave_buffer,alsa_record_ring[card][stream]->
 	 readSpace());
+  WriteAlsaBuffer(card,stream,alsa_wave_buffer,n);
+}
 
-  if(alsa_record_wave[card][stream]->getSamplesPerSec()!=
-     alsa_capture_format[card].sample_rate) {
-    double ratio=(double)alsa_record_wave[card][stream]->getSamplesPerSec()/
-      (double)alsa_capture_format[card].sample_rate;
-    n=Resample(alsa_wave_buffer,alsa_resample_buffer,
-	       n/(2*alsa_input_channels[card][stream]),ratio,
-	       alsa_input_channels[card][stream])*
-      2*alsa_input_channels[card][stream];
-    alsa_record_wave[card][stream]->writeWave(alsa_resample_buffer,n);
-  }
-  else {
-    alsa_record_wave[card][stream]->writeWave(alsa_wave_buffer,n);
+
+void MainObject::WriteAlsaBuffer(int card,int stream,short *buffer,unsigned len)
+{
+  ssize_t s;
+  unsigned char mpeg[2048];
+  unsigned frames;
+  unsigned n;
+
+  frames=len/(2*alsa_record_wave[card][stream]->getChannels());
+  alsa_samples_recorded[card][stream]+=frames;
+  switch(alsa_record_wave[card][stream]->getFormatTag()) {
+  case WAVE_FORMAT_PCM:
+    alsa_record_wave[card][stream]->writeWave(buffer,len);
+    break;
+
+  case WAVE_FORMAT_MPEG:
+#ifdef HAVE_TWOLAME
+    for(unsigned i=0;i<frames;i+=1152) {
+      if((i+1152)>frames) {
+	n=frames-i;
+      }
+      else {
+	n=1152;
+      }
+      if((s=twolame_encode_buffer_interleaved(twolame_lameopts[card][stream],
+		   buffer+i*alsa_record_wave[card][stream]->getChannels(),
+					      n,mpeg,2048))>=0) {
+	alsa_record_wave[card][stream]->writeWave(mpeg,s);
+      }
+      else {
+	LogLine(RDConfig::LogErr,QString().
+	   sprintf("TwoLAME encode error, card: %d, stream: %d",card,stream));
+      }
+    }
+#endif  // HAVE_TWOLAME
+    break;
   }
 }
 
 
 void MainObject::FillAlsaOutputStream(int card,int stream)
 {
+  unsigned mpeg_frames=0;
+  unsigned frame_offset=0;
+  int m=0;
+  int n=0;
+  double ratio=0.0;
   int free=(alsa_play_ring[card][stream]->writeSpace()-1);
   if(free<=0) {
     return;
   }
-  double ratio=(double)alsa_play_format[card].sample_rate/
+  ratio=(double)alsa_play_format[card].sample_rate/
     (double)alsa_play_wave[card][stream]->getSamplesPerSec();
-  free=(int)((double)free/ratio)/(2*alsa_output_channels[card][stream])*
-    (2*alsa_output_channels[card][stream]);
-  int n=alsa_play_wave[card][stream]->readWave(alsa_wave_buffer,free);
-  if(n!=free) {
-    alsa_eof[card][stream]=true;
-  }
-  if(alsa_play_wave[card][stream]->getSamplesPerSec()!=
-     alsa_play_format[card].sample_rate) {
-    n=Resample(alsa_wave_buffer,alsa_resample_buffer,
-	       n/(2*alsa_output_channels[card][stream]),ratio,
-	       alsa_output_channels[card][stream])*
-      2*alsa_output_channels[card][stream];
-    alsa_play_ring[card][stream]->write((char *)alsa_resample_buffer,n);
-  }
-  else {
-    alsa_play_ring[card][stream]->write((char *)alsa_wave_buffer,n);
+  switch(alsa_play_wave[card][stream]->getFormatTag()) {
+  case WAVE_FORMAT_PCM:
+  case WAVE_FORMAT_VORBIS:
+    free=(int)((double)free/ratio)/(2*alsa_output_channels[card][stream])*
+      (2*alsa_output_channels[card][stream]);
+    n=alsa_play_wave[card][stream]->readWave(alsa_wave_buffer,free);
+    if(n!=free) {
+      alsa_eof[card][stream]=true;
+      alsa_stop_timer[card][stream]->stop();
+    }
+    break;
+
+  case WAVE_FORMAT_MPEG:
+#ifdef HAVE_MAD
+    mpeg_frames=free/(2304*alsa_output_channels[card][stream]);
+    free=mpeg_frames*2304*alsa_output_channels[card][stream];
+    for(unsigned i=0;i<mpeg_frames;i++) {
+      m=alsa_play_wave[card][stream]->
+	readWave(mad_mpeg[card][stream]+mad_left_over[card][stream],
+		 mad_frame_size[card][stream]);
+      if(m==mad_frame_size[card][stream]) {
+	mad_stream_buffer(&mad_stream[card][stream],mad_mpeg[card][stream],
+			  m+mad_left_over[card][stream]);
+	while(mad_frame_decode(&mad_frame[card][stream],
+			       &mad_stream[card][stream])==0) {
+	  mad_synth_frame(&mad_synth[card][stream],&mad_frame[card][stream]);
+	  n+=(2*alsa_output_channels[card][stream]*
+	      mad_synth[card][stream].pcm.length);
+	  for(int j=0;j<mad_synth[card][stream].pcm.length;j++) {
+	    for(int k=0;k<mad_synth[card][stream].pcm.channels;k++) {
+	      alsa_wave_buffer[frame_offset+
+			       j*mad_synth[card][stream].pcm.channels+k]=
+		(short)(32768.0*mad_f_todouble(mad_synth[card][stream].
+					       pcm.samples[k][j]));
+	    }
+	  }
+	  frame_offset+=(mad_synth[card][stream].pcm.length*
+			 mad_synth[card][stream].pcm.channels);
+	}
+      }
+      else {  // End-of-file, read out last samples
+	if(!alsa_eof[card][stream]) {
+	  memset(mad_mpeg[card][stream]+mad_left_over[card][stream],0,
+		 MAD_BUFFER_GUARD);
+	  mad_stream_buffer(&mad_stream[card][stream],
+			    mad_mpeg[card][stream],
+			    MAD_BUFFER_GUARD+mad_left_over[card][stream]);
+	  if(mad_frame_decode(&mad_frame[card][stream],
+			      &mad_stream[card][stream])==0) {
+	    mad_synth_frame(&mad_synth[card][stream],
+			    &mad_frame[card][stream]);
+	    n+=(alsa_output_channels[card][stream]*
+		mad_synth[card][stream].pcm.length);
+	    for(int j=0;j<mad_synth[card][stream].pcm.length;j++) {
+	      for(int k=0;k<mad_synth[card][stream].pcm.channels;k++) {
+		alsa_wave_buffer[frame_offset+
+				 j*mad_synth[card][stream].pcm.channels+k]=
+		  (short)(32768.0*mad_f_todouble(mad_synth[card][stream].
+						 pcm.samples[k][j]));
+	      }
+	    }
+	  }
+	}
+	alsa_eof[card][stream]=true;
+	alsa_stop_timer[card][stream]->stop();
+	continue;
+      }
+      mad_left_over[card][stream]=
+	mad_stream[card][stream].bufend-mad_stream[card][stream].next_frame;
+      memmove(mad_mpeg[card][stream],mad_stream[card][stream].next_frame,
+	      mad_left_over[card][stream]);
+    }
+#endif  // HAVE_MAD
+    break;
   }
+  alsa_play_ring[card][stream]->write((char *)alsa_wave_buffer,n);
 }
 #endif  // ALSA
 
@@ -1578,6 +1787,7 @@ void MainObject::AlsaClock()
 	  alsa_stopping[i][j]=false;
 	  alsa_eof[i][j]=false;
 	  alsa_playing[i][j]=false;
+	  printf("stop card: %d  stream: %d\n",i,j);
 	  statePlayUpdate(i,j,2);
 	}
 	if(alsa_playing[i][j]) {
