@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rd.h,v 1.188.2.4 2009/08/04 17:48:29 cvs Exp $
+//      $Id: rd.h,v 1.194.6.3 2012/07/24 20:27:01 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -79,7 +79,7 @@
 /*
  * ALSA Settings
  */
-#define RD_ALSA_DEFAULT_PERIOD_QUANTITY 2
+#define RD_ALSA_DEFAULT_PERIOD_QUANTITY 4
 #define RD_ALSA_DEFAULT_PERIOD_SIZE 1024
 #define RD_ALSA_FADE_INTERVAL 100
 #define RD_ALSA_SAMPLE_RATE_TOLERANCE 100
@@ -173,7 +173,7 @@
  * Reference Analog Level at 0 dBFS (1/100 dB)
  * (thus, -16 dBFS = +4 dBu)
  */
-#define RD_BASE_ANALOG 2000 
+#define RD_BASE_ANALOG 1600 
 
 /*
  * Maximum number of SoundPanels of a given type
@@ -218,6 +218,17 @@
  */
 #define RD_DEFAULT_AUDIO_OWNER "user"
 #define RD_DEFAULT_AUDIO_GROUP "users"
+#define RD_DEFAULT_LABEL "Default Configuration"
+
+/*
+ * Default Audio Store Settings
+ */
+#define RD_DEFAULT_AUDIO_STORE_MOUNT_OPTIONS "defaults"
+
+/*
+ * Default RDSelect Configuration Directory
+ */
+#define RD_DEFAULT_RDSELECT_DIR "/etc/rivendell.d"
 
 /*
  * Default Workstation
@@ -275,16 +286,6 @@
  */
 #define RD_METER_UPDATE_INTERVAL 20
 
-/*
- * The metering shared memory block format
- */
-struct RDMeterBlock {
-  short input_meter[RD_MAX_CARDS][RD_MAX_PORTS][2];
-  short output_meter[RD_MAX_CARDS][RD_MAX_PORTS][2];
-  unsigned output_position[RD_MAX_CARDS][RD_MAX_STREAMS];
-  bool output_state[RD_MAX_CARDS][RD_MAX_PORTS][RD_MAX_STREAMS];
-};
-
 /*
  * The metering block shared memory key
  */
@@ -341,6 +342,7 @@ struct RDMeterBlock {
 #define RIPPER_TEMP_WAV "rdlibrary_rip.wav"
 #define RIPPER_TEMP_PEAK "rdlibrary_rip.dat"
 #define RIPPER_CDDB_USER "rdlibrary"
+#define RIPPER_MAX_SECTORS 20
 
 /*
  * CAE Values
@@ -353,7 +355,7 @@ struct RDMeterBlock {
 /*
  * Default Sample Rate
  */
-#define RD_DEFAULT_SAMPLE_RATE 44100
+#define RD_DEFAULT_SAMPLE_RATE 48000
 
 /*
  * Default Channels
@@ -453,5 +455,26 @@ struct RDMeterBlock {
 #define RD_LIVEWIRE_DEFAULT_LOAD RDLiveWireDestination::LoadHighZ
 #define RD_LIVEWIRE_MAX_SOURCE 0x7FFF
 
+/*
+ * Number of Carts to Include in a 'Limited' Search
+ */
+#define RD_LIMITED_CART_SEARCH_QUANTITY 100
+
+/*
+ * Default title for a new cart
+ */
+#define RD_DEFAULT_CART_TITLE "[new cart]"
+
+/*
+ * Timeout for libcurl (secs)
+ */
+#define RD_CURL_TIMEOUT 1200
+
+/*
+ * Anonymous FTP Credentials
+ */
+#define RD_ANON_FTP_USERNAME "anonymous"
+#define RD_ANON_FTP_PASSWORD "rivendell"
+
 
 #endif  // RD_H
