@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcae.h,v 1.23 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdcae.h,v 1.32.4.1 2012/08/03 16:52:39 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,9 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#ifndef RDCAE_H
+#define RDCAE_H
+
 #include <vector>
 
 #include <qsqldatabase.h>
@@ -27,26 +30,24 @@
 #include <qobject.h>
 #include <qsocketdevice.h>
 #include <qlabel.h>
-#include <rnamespace.h>
+
 #include <rd.h>
 #include <rdcmd_cache.h>
-
-
-#ifndef RDCAE_H
-#define RDCAE_H
-
-
+#include <rdstation.h>
+#include <rdconfig.h>
 
 class RDCae : public QObject
 {
  Q_OBJECT
  public:
+  enum ClockSource {InternalClock=0,AesEbuClock=1,SpDiffClock=2,WordClock=4};
   enum ChannelMode {Normal=0,Swap=1,LeftOnly=2,RightOnly=3};
   enum SourceType {Analog=0,AesEbu=1};
   enum AudioCoding {Pcm16=0,MpegL1=1,MpegL2=2,MpegL3=3};
-  RDCae(QObject *parent=0,const char *name=0);
+  RDCae(RDStation *station,RDConfig *config,
+	QObject *parent=0,const char *name=0);
   ~RDCae();
-  void connectHost(QString hostname,Q_UINT16 hostport,QString password);
+  void connectHost();
   bool loadPlay(int card,QString name,int *stream,int *handle);
   void unloadPlay(int handle);
   void positionPlay(int handle,int pos);
@@ -57,6 +58,7 @@ class RDCae : public QObject
   void unloadRecord(int card,int stream);
   void record(int card,int stream,unsigned length,int threshold);
   void stopRecord(int card,int stream);
+  void setClockSource(int card,RDCae::ClockSource src);
   void setInputVolume(int card,int stream,int level);
   void setOutputVolume(int card,int stream,int port,int level);
   void fadeOutputVolume(int card,int stream,int port,int level,int length);
@@ -68,12 +70,14 @@ class RDCae : public QObject
   void setInputType(int card,int port,RDCae::SourceType type);
   void setPassthroughVolume(int card,int in_port,int out_port,int level);
   bool inputStatus(int card,int port) const;
-  void inputMeterUpdate(int card,int port,short levels[2]) const;
-  void outputMeterUpdate(int card,int port,short levels[2]) const;
+  void inputMeterUpdate(int card,int port,short levels[2]);
+  void outputMeterUpdate(int card,int port,short levels[2]);
   unsigned playPosition(int handle);
   void requestTimescale(int card);
   bool playPortActive(int card,int port,int except_stream=-1);
   void setPlayPortActive(int card,int port,int stream);
+  void connectJackPorts(const QString &out,const QString &in);
+  void disconnectJackPorts(const QString &out,const QString &in);
 
  signals:
   void isConnected(bool state);
@@ -85,7 +89,7 @@ class RDCae : public QObject
   void recordLoaded(int card,int stream);
   void recording(int card,int stream);
   void recordStopped(int card,int stream);
-  void recordUnloaded(int card,int stream);
+  void recordUnloaded(int card,int stream,unsigned msecs);
   void gpiInputChanged(int line,bool state);
   void connected(bool state);
   void inputStatusChanged(int card,int stream,bool state);
@@ -93,7 +97,8 @@ class RDCae : public QObject
   void timescalingSupported(int card,bool state);
 
  private slots:
-  void readyData(int *stream=0,int *handle=0,QString name="");
+  void readyData();
+  void readyData(int *stream,int *handle,QString name);
   void clockData();
   
  private:
@@ -102,19 +107,24 @@ class RDCae : public QObject
   int CardNumber(const char *arg);
   int StreamNumber(const char *arg);
   int GetHandle(const char *arg);
-  RDMeterBlock *meter_block;
+  void UpdateMeters();
   QSocketDevice *cae_socket;
-  QString cae_password;
   bool debug;
   char args[CAE_MAX_ARGS][CAE_MAX_LENGTH];
   int argnum;
   int argptr;
   bool cae_connected;
   bool input_status[RD_MAX_CARDS][RD_MAX_PORTS];
-  int meter_block_id;
   int cae_handle[RD_MAX_CARDS][RD_MAX_STREAMS];
   unsigned cae_pos[RD_MAX_CARDS][RD_MAX_STREAMS];
+  QSocketDevice *cae_meter_socket;
+  short cae_input_levels[RD_MAX_CARDS][RD_MAX_PORTS][2];
+  short cae_output_levels[RD_MAX_CARDS][RD_MAX_PORTS][2];
+  unsigned cae_output_positions[RD_MAX_CARDS][RD_MAX_STREAMS];
+  bool cae_output_status_flags[RD_MAX_CARDS][RD_MAX_PORTS][RD_MAX_STREAMS];
   std::vector<RDCmdCache> delayed_cmds;
+  RDStation *cae_station;
+  RDConfig *cae_config;
 };
 
 
