@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdconfig.h,v 1.12 2007/12/31 18:49:08 fredg Exp $
+//      $Id: rdconfig.h,v 1.18.8.2 2012/08/30 14:15:57 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,6 +23,11 @@
 #ifndef RDCONFIG_H
 #define RDCONFIG_H
 
+#ifndef WIN32
+#include <syslog.h>
+#include <unistd.h>
+#endif  // WIN32
+
 #include <vector>
 
 #include <qstring.h>
@@ -33,6 +38,16 @@
 class RDConfig
 {
  public:
+  enum LogFacility {LogNone=0,LogSyslog=1,LogFile=2};
+#ifdef WIN32
+  enum LogPriority {LogEmerg=0,LogAlert=1,LogCrit=2,
+		    LogErr=3,LogWarning=4,LogNotice=5,
+		    LogInfo=6,LogDebug=7};
+#else
+  enum LogPriority {LogEmerg=LOG_EMERG,LogAlert=LOG_ALERT,LogCrit=LOG_CRIT,
+		    LogErr=LOG_ERR,LogWarning=LOG_WARNING,LogNotice=LOG_NOTICE,
+		    LogInfo=LOG_INFO,LogDebug=LOG_DEBUG};
+#endif  // WIN32
   RDConfig();
   RDConfig(QString filename);
   QString filename() const;
@@ -43,6 +58,12 @@ class RDConfig
   QString mysqlPassword() const;
   QString mysqlDriver() const;
   int mysqlHeartbeatInterval() const;
+  RDConfig::LogFacility logFacility() const;
+  QString logDirectory() const;
+  QString logCoreDumpDirectory() const;
+  QString logPattern() const;
+  bool logXloadDebugData() const;
+  void log(const QString &module,LogPriority prio,const QString &msg);
   int alsaPeriodQuantity() const;
   int alsaPeriodSize() const;
   QString stationName() const;
@@ -52,6 +73,10 @@ class RDConfig
   QString audioRoot() const;
   QString audioExtension() const;
   QString audioFileName (QString cutname);
+  QString label() const;
+  QString audioStoreMountSource() const;
+  QString audioStoreMountType() const;
+  QString audioStoreMountOptions() const;
   QString ripcdLogname() const;
   QString airplayLogname() const;
   QString catchdLogname() const;
@@ -60,7 +85,6 @@ class RDConfig
   bool useStreamMeters() const;
   QString caeLogfile() const;
   bool enableMixerLogging() const;
-  unsigned sampleRate() const;
   unsigned channels() const;
 #ifndef WIN32
   uid_t uid() const;
@@ -84,6 +108,11 @@ class RDConfig
   QString conf_mysql_password;
   QString conf_mysql_driver;
   int conf_mysql_heartbeat_interval;
+  RDConfig::LogFacility conf_log_facility;
+  QString conf_log_directory;
+  QString conf_log_core_dump_directory;
+  QString conf_log_pattern;
+  bool conf_log_xload_debug_data;
   int conf_alsa_period_quantity;
   int conf_alsa_period_size;
   QString conf_station_name;
@@ -92,12 +121,15 @@ class RDConfig
   QString conf_audio_group;
   QString conf_audio_root;
   QString conf_audio_extension;
+  QString conf_label;
+  QString conf_audio_store_mount_source;
+  QString conf_audio_store_mount_type;
+  QString conf_audio_store_mount_options;
   QString conf_ripcd_logname;
   QString conf_airplay_logname;
   QString conf_catchd_logname;
   bool conf_use_stream_meters;
   std::vector<QString> conf_jack_ports[2];
-  unsigned conf_sample_rate;
   unsigned conf_channels;
 #ifndef WIN32
   uid_t conf_uid;
