@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcut.cpp,v 1.67.2.1 2008-11-30 16:33:57 fredg Exp $
+//      $Id: rdcut.cpp,v 1.76.6.3 2012/08/02 20:37:58 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,6 +22,7 @@
 
 #ifndef WIN32
 #include <unistd.h>
+#include <syslog.h>
 #endif  // WIN32
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -38,6 +39,8 @@
 #include <rdconfig.h>
 #include <rddb.h>
 #include <rdescape_string.h>
+#include <rdweb.h>
+#include <rdcopyaudio.h>
 
 //
 // Global Classes
@@ -52,6 +55,12 @@ RDCut::RDCut(const QString &name,bool create,QSqlDatabase *db)
 
   cut_signal=new QSignal();
 
+  if(name.isEmpty()) {
+    cut_number=0;
+    cart_number=0;
+    return;
+  }
+
   if(create) {
     sql=QString().sprintf("INSERT INTO CUTS SET CUT_NAME=\"%s\"",
 			  (const char *)cut_name);
@@ -59,6 +68,7 @@ RDCut::RDCut(const QString &name,bool create,QSqlDatabase *db)
     delete q;
   }
   sscanf((const char *)name+7,"%u",&cut_number);
+  sscanf((const char *)name.left(6),"%u",&cart_number);
 }
 
 
@@ -79,6 +89,7 @@ RDCut::RDCut(unsigned cartnum,int cutnum,bool create,QSqlDatabase *db)
     delete q;
   }
   cut_number=cutnum;
+  cart_number=cartnum;
 }
 
 
@@ -94,23 +105,6 @@ bool RDCut::exists() const
 }
 
 
-bool RDCut::audioExists() const
-{
-  if(!exists()) {
-    return false;
-  }
-#ifndef WIN32
-  RDWaveFile *wave=new RDWaveFile(RDCut::pathName(cut_name)); 
-  if(!wave->openWave()) {
-    delete wave;
-    return false;
-  }
-  delete wave;
-#endif
-  return true;
-}
-
-
 bool RDCut::isValid() const
 {
   return isValid(QDateTime(QDate::currentDate(),QTime::currentTime()));
@@ -180,8 +174,7 @@ unsigned RDCut::cutNumber() const
 
 unsigned RDCut::cartNumber() const
 {
-  return RDGetSqlValue("CUTS","CUT_NAME",cut_name,"CART_NUMBER",cut_db).
-    toUInt();
+  return cart_number;
 }
 
 
@@ -249,6 +242,18 @@ void RDCut::setIsrc(const QString &isrc) const
 }
 
 
+QString RDCut::isci() const
+{
+  return RDGetSqlValue("CUTS","CUT_NAME",cut_name,"ISCI",cut_db).toString();
+}
+
+
+void RDCut::setIsci(const QString &isci) const
+{
+  SetRow("ISCI",isci);
+}
+
+
 unsigned RDCut::length() const
 {
   return RDGetSqlValue("CUTS","CUT_NAME",cut_name,"LENGTH",cut_db).
@@ -411,6 +416,25 @@ void RDCut::setLastPlayDatetime(const QDateTime &datetime,bool valid) const
 }
 
 
+QDateTime RDCut::uploadDatetime(bool *valid) const
+{
+  return 
+    RDGetSqlValue("CUTS","CUT_NAME",cut_name,"UPLOAD_DATETIME",cut_db,valid).
+    toDateTime();
+}
+
+
+void RDCut::setUploadDatetime(const QDateTime &datetime,bool valid) const
+{
+  if(valid) {
+    SetRow("UPLOAD_DATETIME",datetime);
+  }
+  else {
+    SetRow("UPLOAD_DATETIME");
+  }
+}
+
+
 unsigned RDCut::playCounter() const
 {
   return RDGetSqlValue("CUTS","CUT_NAME",cut_name,"PLAY_COUNTER",cut_db).
@@ -784,18 +808,22 @@ void RDCut::logPlayout() const
 }
 
 
-bool RDCut::copyTo(const QString &cutname) const
+bool RDCut::copyTo(RDStation *station,RDUser *user,
+		   const QString &cutname) const
 {
-#ifndef WIN32
+#ifdef WIN32
+  return false;
+#else
   QString sql;
   RDSqlQuery *q;
+  bool ret=true;
 
   //
   // Copy the Database Record
   //
   sql=
     QString().sprintf("select DESCRIPTION,OUTCUE,LENGTH,\
-                       ORIGIN_DATETIME,ORIGIN_NAME,CODING_FORMAT,SAMPLE_RATE,\
+                       CODING_FORMAT,SAMPLE_RATE,\
                        BIT_RATE,CHANNELS,PLAY_GAIN,START_POINT,END_POINT,\
                        FADEUP_POINT,FADEDOWN_POINT,SEGUE_START_POINT,\
                        SEGUE_END_POINT,HOOK_START_POINT,HOOK_END_POINT,\
@@ -804,10 +832,11 @@ bool RDCut::copyTo(const QString &cutname) const
   q=new RDSqlQuery(sql);
   if(q->first()) {
     sql=QString().sprintf("update CUTS set\
+                           PLAY_COUNTER=0,\
                            DESCRIPTION=\"%s\",\
                            OUTCUE=\"%s\",\
                            LENGTH=%u,\
-                           ORIGIN_DATETIME=\"%s\",\
+                           ORIGIN_DATETIME=now(),\
                            ORIGIN_NAME=\"%s\",\
                            CODING_FORMAT=%u,\
                            SAMPLE_RATE=%u,\
@@ -827,12 +856,13 @@ bool RDCut::copyTo(const QString &cutname) const
 			  (const char *)q->value(0).toString().utf8(),
 			  (const char *)q->value(1).toString().utf8(),
 			  q->value(2).toUInt(),
-			  (const char *)q->value(3).toString().utf8(),
-			  (const char *)q->value(4).toString().utf8(),
+			  (const char *)RDEscapeString(station->name()),
+			  q->value(3).toUInt(),
+			  q->value(4).toUInt(),
 			  q->value(5).toUInt(),
 			  q->value(6).toUInt(),
-			  q->value(7).toUInt(),
-			  q->value(8).toUInt(),
+			  q->value(7).toInt(),
+			  q->value(8).toInt(),
 			  q->value(9).toInt(),
 			  q->value(10).toInt(),
 			  q->value(11).toInt(),
@@ -841,9 +871,7 @@ bool RDCut::copyTo(const QString &cutname) const
 			  q->value(14).toInt(),
 			  q->value(15).toInt(),
 			  q->value(16).toInt(),
-			  q->value(17).toInt(),
-			  q->value(18).toInt(),
-			  q->value(19).toInt(),			  
+			  q->value(17).toInt(),			  
 			  (const char *)cutname);
   }
   delete q;
@@ -853,16 +881,25 @@ bool RDCut::copyTo(const QString &cutname) const
   //
   // Copy the Audio
   //
+  RDCopyAudio *conv=new RDCopyAudio(station);
+  conv->setSourceCartNumber(cart_number);
+  conv->setSourceCutNumber(cut_number);
+  conv->setDestinationCartNumber(RDCut::cartNumber(cutname));
+  conv->setDestinationCutNumber(RDCut::cutNumber(cutname));
+  ret=conv->runCopy(user->name(),user->password())==RDCopyAudio::ErrorOk;
+  delete conv;
+  /*
   QString srcname=RDCut::pathName(cut_name); 
   QString destname=RDCut::pathName(cutname); 
   FileCopy(srcname,destname);
+  */
 
+  return ret;
 #endif
-  return true;
 }
 
 
-void RDCut::getMetadata(RDWaveData *data)
+void RDCut::getMetadata(RDWaveData *data) const
 {
   QString sql;
   RDSqlQuery *q;
@@ -870,7 +907,9 @@ void RDCut::getMetadata(RDWaveData *data)
   sql=QString().sprintf("select DESCRIPTION,OUTCUE,ISRC,ORIGIN_DATETIME,\
                          START_DATETIME,END_DATETIME,SEGUE_START_POINT,\
                          SEGUE_END_POINT,TALK_START_POINT,TALK_END_POINT,\
-                         START_POINT,END_POINT where CUT_NAME=\"%s\"",
+                         START_POINT,END_POINT,HOOK_START_POINT,\
+                         HOOK_END_POINT,FADEUP_POINT,FADEDOWN_POINT \
+                         from CUTS where CUT_NAME=\"%s\"",
 			(const char *)cut_name);
   q=new RDSqlQuery(sql);
   if(q->first()) {
@@ -889,13 +928,17 @@ void RDCut::getMetadata(RDWaveData *data)
     data->setIntroEndPos(q->value(9).toInt());
     data->setStartPos(q->value(10).toInt());
     data->setEndPos(q->value(11).toInt());
+    data->setHookStartPos(q->value(12).toInt());
+    data->setHookEndPos(q->value(13).toInt());
+    data->setFadeUpPos(q->value(14).toInt());
+    data->setFadeDownPos(q->value(15).toInt());
     data->setMetadataFound(true);
   }
   delete q;
 }
 
 
-void RDCut::setMetadata(RDWaveData *data)
+void RDCut::setMetadata(RDWaveData *data) const
 {
   QString sql="update CUTS set ";
   if(!data->title().isEmpty()) {
@@ -974,7 +1017,27 @@ void RDCut::setMetadata(RDWaveData *data)
       }
     }
   }
-  if(data->startDate().isValid()) {
+  if(data->startDate().isValid()&&data->endDate().isValid()&&
+     (data->startTime().isNull())&&(data->endTime().isNull())) {
+    data->setEndTime(QTime(23,59,59));
+  }
+  if((data->hookStartPos()>=data->startPos())&&
+     (data->hookStartPos()<=data->endPos())&&
+     (data->hookEndPos()>=data->startPos())&&
+     (data->hookEndPos()<=data->endPos())&&
+     (data->hookEndPos()>data->hookStartPos())) {
+    sql+=QString().sprintf("HOOK_START_POINT=%d,HOOK_END_POINT=%d,",
+			   data->hookStartPos(),data->hookEndPos());
+  }
+  if((data->fadeUpPos()>data->startPos())&&
+     (data->fadeUpPos()<=data->endPos())) {
+    sql+=QString().sprintf("FADEUP_POINT=%d,",data->fadeUpPos());
+  }
+  if((data->fadeDownPos()>data->startPos())&&
+     (data->fadeDownPos()<=data->endPos())) {
+    sql+=QString().sprintf("FADEDOWN_POINT=%d,",data->fadeDownPos());
+  }
+  if((data->startDate()>QDate(1900,1,1))&&(data->endDate().year()<8000)) {
     if(data->startTime().isValid()) {
     sql+=QString().sprintf("START_DATETIME=\"%s %s\",",
 			   (const char *)data->startDate().
@@ -1012,22 +1075,124 @@ void RDCut::setMetadata(RDWaveData *data)
 }
 
 
-bool RDCut::checkInRecording(const QString &stationname) const
+QString RDCut::xml() const
+{
+#ifdef WIN32
+  return QString();
+#else
+  QString sql;
+  RDSqlQuery *q;
+  QString ret="";
+
+  sql=QString().sprintf("select EVERGREEN,DESCRIPTION,OUTCUE,ISRC,ISCI,\
+                         LENGTH,ORIGIN_DATETIME,START_DATETIME,END_DATETIME,\
+                         SUN,MON,TUE,WED,THU,FRI,SAT,START_DAYPART,END_DAYPART,\
+                         ORIGIN_NAME,WEIGHT,LAST_PLAY_DATETIME,\
+                         PLAY_COUNTER,LOCAL_COUNTER,VALIDITY,CODING_FORMAT,\
+                         SAMPLE_RATE,BIT_RATE,CHANNELS,PLAY_GAIN,START_POINT,\
+                         END_POINT,FADEUP_POINT,FADEDOWN_POINT,\
+                         SEGUE_START_POINT,SEGUE_END_POINT,SEGUE_GAIN\
+                         HOOK_START_POINT,HOOK_END_POINT,\
+                         TALK_START_POINT,TALK_END_POINT \
+                         from CUTS where CUT_NAME=\"%s\"",
+			(const char *)cut_name);
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    ret+="<cut>\n";
+    ret+="  "+RDXmlField("cutName",cut_name);
+    ret+="  "+RDXmlField("cartNumber",cart_number);
+    ret+="  "+RDXmlField("cutNumber",cut_number);
+    ret+="  "+RDXmlField("evergreen",RDBool(q->value(0).toString()));
+    ret+="  "+RDXmlField("description",q->value(1).toString());
+    ret+="  "+RDXmlField("outcue",q->value(2).toString());
+    ret+="  "+RDXmlField("isrc",q->value(3).toString());
+    ret+="  "+RDXmlField("isci",q->value(4).toString());
+    ret+="  "+RDXmlField("length",q->value(5).toUInt());
+    if(q->value(6).isNull()) {
+      ret+="  "+RDXmlField("originDatetime","");
+    }
+    else {
+      ret+="  "+RDXmlField("originDatetime",q->value(6).toDateTime());
+    }
+    if(q->value(7).isNull()) {
+      ret+="  "+RDXmlField("startDatetime","");
+    }
+    else {
+      ret+="  "+RDXmlField("startDatetime",q->value(7).toDateTime());
+    }
+    if(q->value(8).isNull()) {
+      ret+="  "+RDXmlField("endDatetime","");
+    }
+    else {
+      ret+="  "+RDXmlField("endDatetime",q->value(8).toDateTime());
+    }
+    ret+="  "+RDXmlField("sun",RDBool(q->value(9).toString()));
+    ret+="  "+RDXmlField("mon",RDBool(q->value(10).toString()));
+    ret+="  "+RDXmlField("tue",RDBool(q->value(11).toString()));
+    ret+="  "+RDXmlField("wed",RDBool(q->value(12).toString()));
+    ret+="  "+RDXmlField("thu",RDBool(q->value(13).toString()));
+    ret+="  "+RDXmlField("fri",RDBool(q->value(14).toString()));
+    ret+="  "+RDXmlField("sat",RDBool(q->value(15).toString()));
+    if(q->value(16).isNull()) {
+      ret+="  "+RDXmlField("startDaypart","");
+    }
+    else {
+      ret+="  "+RDXmlField("startDaypart",q->value(16).toTime());
+    }
+    if(q->value(17).isNull()) {
+      ret+="  "+RDXmlField("endDaypart","");
+    }
+    else {
+      ret+="  "+RDXmlField("endDaypart",q->value(17).toTime());
+    }
+    ret+="  "+RDXmlField("originName",q->value(18).toString());
+    ret+="  "+RDXmlField("weight",q->value(19).toUInt());
+    ret+="  "+RDXmlField("lastPlayDatetime",q->value(20).toDateTime());
+    ret+="  "+RDXmlField("playCounter",q->value(21).toUInt());
+    ret+="  "+RDXmlField("localCounter",q->value(22).toUInt());
+    ret+="  "+RDXmlField("validity",q->value(23).toUInt());
+    ret+="  "+RDXmlField("codingFormat",q->value(24).toUInt());
+    ret+="  "+RDXmlField("sampleRate",q->value(25).toUInt());
+    ret+="  "+RDXmlField("bitRate",q->value(26).toUInt());
+    ret+="  "+RDXmlField("channels",q->value(27).toUInt());
+    ret+="  "+RDXmlField("playGain",q->value(28).toUInt());
+    ret+="  "+RDXmlField("startPoint",q->value(29).toInt());
+    ret+="  "+RDXmlField("endPoint",q->value(30).toInt());
+    ret+="  "+RDXmlField("fadeupPoint",q->value(31).toInt());
+    ret+="  "+RDXmlField("fadedownPoint",q->value(32).toInt());
+    ret+="  "+RDXmlField("segueStartPoint",q->value(33).toInt());
+    ret+="  "+RDXmlField("segueEndPoint",q->value(34).toInt());
+    ret+="  "+RDXmlField("segueGain",q->value(35).toInt());
+    ret+="  "+RDXmlField("hookStartPoint",q->value(36).toInt());
+    ret+="  "+RDXmlField("hookEndPoint",q->value(37).toInt());
+    ret+="  "+RDXmlField("talkStartPoint",q->value(38).toInt());
+    ret+="  "+RDXmlField("talkEndPoint",q->value(39).toInt());
+    ret+="</cut>\n";
+  }
+  delete q;
+  return ret;
+#endif  // WIN32
+}
+
+
+bool RDCut::checkInRecording(const QString &stationname,RDSettings *settings,
+			     unsigned msecs) const
 {
 #ifdef WIN32
   return false;
 #else
   QString sql;
   RDSqlQuery *q;
+  int format;
 
-  RDWaveFile *wavefile=new RDWaveFile(RDCut::pathName(cut_name));
-  if(!wavefile->openWave()) {
-    delete wavefile;
-    return false;
-  }
-  int format=0;
-  if(wavefile->getFormatTag()==WAVE_FORMAT_MPEG) {
+  switch(settings->format()) {
+  case RDSettings::MpegL2:
     format=1;
+    break;
+
+  default:
+    format=0;
+    break;
   }
   sql=QString().sprintf("update CUTS set START_POINT=0,END_POINT=%d,\
                          FADEUP_POINT=-1,FADEDOWN_POINT=-1,\
@@ -1037,14 +1202,15 @@ bool RDCut::checkInRecording(const QString &stationname) const
                          PLAY_GAIN=0,PLAY_COUNTER=0,LOCAL_COUNTER=0,\
                          CODING_FORMAT=%d,SAMPLE_RATE=%d,\
                          BIT_RATE=%d,CHANNELS=%d,LENGTH=%d,\
-                         ORIGIN_DATETIME=\"%s %s\",ORIGIN_NAME=\"%s\" \
+                         ORIGIN_DATETIME=\"%s %s\",ORIGIN_NAME=\"%s\",\
+                         UPLOAD_DATETIME=null \
                          where CUT_NAME=\"%s\"",
-			wavefile->getExtTimeLength(),
+			msecs,
 			format,
-			wavefile->getSamplesPerSec(),
-			wavefile->getHeadBitRate(),
-			wavefile->getChannels(),
-			wavefile->getExtTimeLength(),
+			settings->sampleRate(),
+			settings->bitRate(),
+			settings->channels(),
+			msecs,
 			(const char *)QDate::currentDate().
 			toString("yyyy-MM-dd"),
 			(const char *)QTime::currentTime().
@@ -1053,8 +1219,6 @@ bool RDCut::checkInRecording(const QString &stationname) const
 			(const char *)cut_name);
   q=new RDSqlQuery(sql);
   delete q;
-  wavefile->closeWave();
-  delete wavefile;
   return true;
 #endif  // WIN32
 }
@@ -1105,6 +1269,13 @@ void RDCut::autoTrim(RDCut::AudioEnd end,int level)
   }
   setStartPoint(start_point);
   setEndPoint(end_point);
+  if(segueEndPoint()>end_point) {
+    setSegueEndPoint(end_point);
+  }
+  if(segueStartPoint()>end_point) {
+    setSegueStartPoint(-1);
+    setSegueEndPoint(-1);
+  }
   setLength(end_point-start_point);
   delete wave;
 #endif  // WIN32
@@ -1234,6 +1405,30 @@ void RDCut::disconnect(QObject *receiver,const char *member) const
 }
 
 
+QString RDCut::cutName(unsigned cartnum,unsigned cutnum)
+{
+  return QString().sprintf("%06u_%03u",cartnum,cutnum);
+}
+
+
+unsigned RDCut::cartNumber(const QString &cutname)
+{
+  return cutname.left(6).toUInt();
+}
+
+
+unsigned RDCut::cutNumber(const QString &cutname)
+{
+  return cutname.right(3).toUInt();
+}
+
+
+bool RDCut::exists(unsigned cartnum,unsigned cutnum)
+{
+  return RDCut::exists(RDCut::cutName(cartnum,cutnum));
+}
+
+
 bool RDCut::exists(const QString &cutname)
 {
   RDSqlQuery *q=new RDSqlQuery(QString().sprintf("select CUT_NAME from CUTS\
@@ -1245,6 +1440,12 @@ bool RDCut::exists(const QString &cutname)
 }
 
 
+QString RDCut::pathName(unsigned cartnum,unsigned cutnum)
+{
+  return RDCut::pathName(RDCut::cutName(cartnum,cutnum));
+}
+
+
 QString RDCut::pathName(const QString &cutname)
 {
   return RDConfiguration()->audioFileName(cutname); 
