@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2007 Dan Mills <dmills@exponent.myzen.co.uk>
 //
-//      $Id: rddb.cpp,v 1.6 2008/01/02 12:18:38 fredg Exp $
+//      $Id: rddb.cpp,v 1.13.4.1 2012/05/21 20:49:26 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,17 +29,17 @@
 #include <qsqlerror.h>
 #include <assert.h>
 
-#include "rdconfig.h"
 #include "rddb.h"
 #include "rddbheartbeat.h"
 
 static QSqlDatabase *db = NULL;
 static RDSqlDatabaseStatus * dbStatus = NULL;
 
-QSqlDatabase * RDInitDb (QString *error)
+QSqlDatabase *RDInitDb (unsigned *schema,QString *error)
 {
   static bool firsttime = true;
 
+  *schema=0;
   RDConfig *cf = RDConfiguration();
   cf->load();
   assert (cf);
@@ -68,6 +68,12 @@ QSqlDatabase * RDInitDb (QString *error)
     new RDDbHeartbeat(cf->mysqlHeartbeatInterval());
     firsttime = false;
   }
+  QSqlQuery *q=new QSqlQuery("select DB from VERSION");
+  if(q->first()) {
+    *schema=q->value(0).toUInt();
+  }
+  delete q;
+
   return db;
 }
 
@@ -75,13 +81,19 @@ RDSqlQuery::RDSqlQuery (const QString &query, QSqlDatabase *dbase):
   QSqlQuery (query,dbase)
 {
   // With any luck, by the time we get here, we have already done the biz...
+  unsigned schema;
   if (!isActive()){ //DB Offline?
+    QString err=QObject::tr("invalid SQL or failed DB connection:")+" "+query;
+    fprintf(stderr,"%s\n",(const char *)err);
+#ifndef WIN32
+    syslog(LOG_ERR,(const char *)err);
+#endif  // WIN32
     QSqlDatabase *ldb = QSqlDatabase::database();
     // Something went wrong with the DB, trying a reconnect
     ldb->removeDatabase(RDConfiguration()->mysqlDbname());
     ldb->close();
     db = NULL;
-    RDInitDb ();
+    RDInitDb (&schema);
     QSqlQuery::prepare (query);
     QSqlQuery::exec ();
     if (RDDbStatus()){
@@ -101,7 +113,7 @@ void RDSqlDatabaseStatus::sendRecon()
     discon = false;
     emit reconnected();
     fprintf (stderr,"Database connection restored.\n");
-    emit logText (QString(tr("Database connection restored.")));
+    emit logText(RDConfig::LogErr,QString(tr("Database connection restored.")));
   }
 }
 
@@ -110,7 +122,8 @@ void RDSqlDatabaseStatus::sendDiscon(QString query)
   if (!discon){
     emit connectionFailed();
     fprintf (stderr,"Database connection failed: %s\n",(const char *)query);
-    emit logText (QString(tr("Database connection failed : ")) + query);
+    emit logText(RDConfig::LogErr,
+		 QString(tr("Database connection failed : ")) + query);
     discon = true;
   }
 }
