@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdescape_string.cpp,v 1.9 2007/09/08 20:01:13 dmills Exp $
+//      $Id: rdescape_string.cpp,v 1.17 2010/07/29 19:32:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,8 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <vector>
+
 #include <rdescape_string.h>
 
 QString RDEscapeString(QString const &str)
@@ -28,10 +30,6 @@ QString RDEscapeString(QString const &str)
 
   for(unsigned i=0;i<str.length();i++) {
     switch(((const char *)str)[i]) {
-	case '%':
-	  res+=QString("\\\%");
-	  break;
-
 	case '(':
 	  res+=QString("\\\(");
 	  break;
@@ -56,10 +54,6 @@ QString RDEscapeString(QString const &str)
 	  res+=QString("\\`");
 	  break;
 
-	case ' ':
-	  res+=QString("\\")+QString(" ");
-	  break;
-
 	case '[':
 	  res+=QString("\\\[");
 	  break;
@@ -68,10 +62,19 @@ QString RDEscapeString(QString const &str)
 	  res+=QString("\\\'");
 	  break;
 
+	case '\\':
+	  res+=QString("\\");
+	  res+=QString("\\");
+	  break;
+
 	case '?':
 	  res+=QString("\\\?");
 	  break;
 
+	case ' ':
+	  res+=QString("\\ ");
+	  break;
+
 	case '&':
 	  res+=QString("\\&");
 	  break;
@@ -80,6 +83,18 @@ QString RDEscapeString(QString const &str)
 	  res+=QString("\\;");
 	  break;
 
+        case '<':
+	  res+=QString("\\<");
+	  break;
+
+        case '>':
+	  res+=QString("\\>");
+	  break;
+
+        case '|':
+	  res+=QString("\\|");
+	  break;
+
 	default:
 	  res+=((const char *)str)[i];
 	  break;
