@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdgroup.cpp,v 1.18.2.1 2008/11/30 00:32:57 fredg Exp $
+//      $Id: rdgroup.cpp,v 1.23 2010/07/29 19:32:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,6 +24,7 @@
 #include <rdgroup.h>
 #include <rddb.h>
 #include <rdescape_string.h>
+#include <rdweb.h>
 
 //
 // Global Classes
@@ -293,6 +294,51 @@ bool RDGroup::cartNumberValid(unsigned cartnum) const
 }
 
 
+QString RDGroup::xml() const
+{
+  QString sql;
+  RDSqlQuery *q;
+  QString ret="";
+
+  sql=QString().sprintf("select DESCRIPTION,DEFAULT_CART_TYPE,DEFAULT_LOW_CART,\
+                                DEFAULT_HIGH_CART,CUT_SHELFLIFE,DEFAULT_TITLE,\
+                                ENFORCE_CART_RANGE,REPORT_TFC,REPORT_MUS,\
+                                ENABLE_NOW_NEXT,COLOR \
+                                from GROUPS where NAME=\"%s\"",
+			(const char *)RDEscapeString(group_name));
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    ret+="<group>\n";
+    ret+="  "+RDXmlField("name",group_name);
+    ret+="  "+RDXmlField("description",q->value(0).toString());
+    switch(q->value(1).toUInt()) {
+    case RDCart::Audio:
+      ret+="  "+RDXmlField("defaultCartType","audio");
+      break;
+
+    case RDCart::Macro:
+      ret+="  "+RDXmlField("defaultCartType","macro");
+      break;
+
+    case RDCart::All:
+      break;
+    }
+    ret+="  "+RDXmlField("defaultLowCart",q->value(2).toUInt());
+    ret+="  "+RDXmlField("defaultHighCart",q->value(3).toUInt());
+    ret+="  "+RDXmlField("cutShelfLife",q->value(4).toInt());
+    ret+="  "+RDXmlField("defaultTitle",q->value(5).toString());
+    ret+="  "+RDXmlField("enforceCartRange",RDBool(q->value(6).toString()));
+    ret+="  "+RDXmlField("reportTfc",RDBool(q->value(7).toString()));
+    ret+="  "+RDXmlField("reportMus",RDBool(q->value(8).toString()));
+    ret+="  "+RDXmlField("enableNowNext",RDBool(q->value(9).toString()));
+    ret+="  "+RDXmlField("color",q->value(10).toString());
+    ret+="</group>\n";
+  }
+  delete q;
+  return ret;
+}
+
+
 void RDGroup::SetRow(const QString &param,int value) const
 {
   RDSqlQuery *q;
