@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdttydevice.h,v 1.1 2007/09/14 14:06:24 fredg Exp $
+//    $Id: rdttydevice.h,v 1.5 2011/05/04 18:09:06 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -71,6 +71,10 @@ class RDTTYDevice : public QIODevice
    **/
   void close();
 
+#ifndef WIN32
+  int socket();
+#endif  // WIN32
+
   /**
    * This method is reimplemented from the QIODevice class, the API is
    * unaffected.
