@@ -22,8 +22,16 @@
 #ifndef RDWEB_H
 #define RDWEB_H
 
+#include <map>
+
 #include <qstring.h>
+#include <qdatetime.h>
 #include <qhostaddress.h>
+#include <qstringlist.h>
+
+#ifndef WIN32
+#include <rdaudioconvert.h>
+#endif  // WIN32
 
 //
 // Data Structure Sizes
@@ -46,7 +54,11 @@ extern int RDEncodeSQLString(char *,int);
 extern int RDDecodeString(char *);
 extern int RDPutPlaintext(char *,int);
 extern int RDPurgePlaintext(char *,int);
-extern void RDCgiError(const char *);
+extern void RDCgiError(const char *str,int resp_code=200);
+#ifndef WIN32
+extern void RDXMLResult(const char *str,int resp_code,
+			RDAudioConvert::ErrorCode err=RDAudioConvert::ErrorOk);
+#endif  // WIN32
 extern int RDBufferDiff(char *,int,int,int);
 extern void RDPruneAmp(char *);
 extern int RDEscapeQuotes(const char *src,char *dest,int maxlen);
@@ -58,4 +70,19 @@ extern QString RDAuthenticateSession(long int session_id,
 extern void RDLogoutSession(long int session_id,const QHostAddress &addr);
 extern QString RDEscapeWebString(const QString &str);
 
+extern bool RDParsePost(std::map<QString,QString> *vars);
+extern QString RDXmlField(const QString &tag,const QString &value);
+extern QString RDXmlField(const QString &tag,const char *value);
+extern QString RDXmlField(const QString &tag,const int value);
+extern QString RDXmlField(const QString &tag,const unsigned value);
+extern QString RDXmlField(const QString &tag,const bool value);
+extern QString RDXmlField(const QString &tag,const QDateTime &value);
+extern QString RDXmlField(const QString &tag,const QTime &value);
+extern QString RDXmlEscape(const QString &str);
+extern QString RDXmlUnescape(const QString &str);
+extern QString RDWebDateTime(const QDateTime &datetime);
+extern QDateTime RDGetWebDateTime(const QString &str);
+extern QTime RDGetWebTime(const QString &str);
+extern int RDGetWebMonth(const QString &str);
+
 #endif  // RDWEB_H
