@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_decks.cpp,v 1.31 2008/04/03 16:50:06 fredg Exp $
+//      $Id: edit_decks.cpp,v 1.35 2012/02/13 19:26:14 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,7 +34,8 @@
 #include <edit_decks.h>
 
 
-EditDecks::EditDecks(RDStation *station,QWidget *parent,const char *name)
+EditDecks::EditDecks(RDStation *station,RDStation *cae_station,
+		     QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   //
@@ -79,7 +80,7 @@ EditDecks::EditDecks(RDStation *station,QWidget *parent,const char *name)
   //
   // Settings Label
   //
-  label=new QLabel("Settings",this,"settings_label");
+  label=new QLabel(tr("Settings"),this,"settings_label");
   label->setGeometry(10,40,100,24);
   label->setFont(big_font);
 
@@ -128,37 +129,26 @@ EditDecks::EditDecks(RDStation *station,QWidget *parent,const char *name)
   label->setGeometry(10,136,110,24);
   label->setAlignment(AlignRight|AlignVCenter);
 
-  //
-  // Sample Rate
-  //
-  edit_samprate_box=new QComboBox(this,"edit_samprate_box");
-  edit_samprate_box->setGeometry(125,160,90,24);
-  edit_samprate_box->setInsertionPolicy(QComboBox::NoInsertion);
-  label=new QLabel(edit_samprate_box,tr("Sample Rate:"),this,
-			     "edit_samprate_label");
-  label->setGeometry(10,160,110,24);
-  label->setAlignment(AlignRight|AlignVCenter);
-
   //
   // Bit Rate
   //
   edit_bitrate_box=new QComboBox(this,"edit_bitrate_box");
-  edit_bitrate_box->setGeometry(125,184,140,24);
+  edit_bitrate_box->setGeometry(125,160,140,24);
   edit_bitrate_box->setInsertionPolicy(QComboBox::NoInsertion);
   edit_bitrate_label=new QLabel(edit_bitrate_box,tr("Bit Rate:"),this,
 			     "edit_bitrate_label");
-  edit_bitrate_label->setGeometry(10,184,110,24);
+  edit_bitrate_label->setGeometry(10,160,110,24);
   edit_bitrate_label->setAlignment(AlignRight|AlignVCenter);
 
   //
   // Switcher Station
   //
   edit_swstation_box=new QComboBox(this,"edit_swstation_box");
-  edit_swstation_box->setGeometry(125,214,250,24);
+  edit_swstation_box->setGeometry(125,190,250,24);
   edit_swstation_box->setInsertionPolicy(QComboBox::NoInsertion);
   edit_swstation_label=new QLabel(edit_swstation_box,tr("Switcher Host:"),this,
 			     "edit_swstation_label");
-  edit_swstation_label->setGeometry(10,214,110,24);
+  edit_swstation_label->setGeometry(10,190,110,24);
   edit_swstation_label->setAlignment(AlignRight|AlignVCenter);
   connect(edit_swstation_box,SIGNAL(activated(const QString &)),
 	  this,SLOT(stationActivatedData(const QString &)));
@@ -167,12 +157,12 @@ EditDecks::EditDecks(RDStation *station,QWidget *parent,const char *name)
   // Switcher Matrix
   //
   edit_swmatrix_box=new QComboBox(this,"edit_swmatrix_box");
-  edit_swmatrix_box->setGeometry(125,238,250,24);
+  edit_swmatrix_box->setGeometry(125,214,250,24);
   edit_swmatrix_box->setInsertionPolicy(QComboBox::NoInsertion);
   edit_swmatrix_box->setDisabled(true);
   edit_swmatrix_label=new QLabel(edit_swmatrix_box,tr("Switcher Matrix:"),this,
 			     "edit_swmatrix_label");
-  edit_swmatrix_label->setGeometry(10,238,110,24);
+  edit_swmatrix_label->setGeometry(10,214,110,24);
   edit_swmatrix_label->setAlignment(AlignRight|AlignVCenter);
   edit_swmatrix_label->setDisabled(true);
   connect(edit_swmatrix_box,SIGNAL(activated(const QString &)),
@@ -182,12 +172,12 @@ EditDecks::EditDecks(RDStation *station,QWidget *parent,const char *name)
   // Switcher Output
   //
   edit_swoutput_box=new QComboBox(this,"edit_swoutput_box");
-  edit_swoutput_box->setGeometry(125,262,250,24);
+  edit_swoutput_box->setGeometry(125,238,250,24);
   edit_swoutput_box->setInsertionPolicy(QComboBox::NoInsertion);
   edit_swoutput_box->setDisabled(true);
   edit_swoutput_label=new QLabel(edit_swoutput_box,tr("Switcher Output:"),this,
 			     "edit_swoutput_label");
-  edit_swoutput_label->setGeometry(10,262,110,24);
+  edit_swoutput_label->setGeometry(10,238,110,24);
   edit_swoutput_label->setAlignment(AlignRight|AlignVCenter);
   edit_swoutput_label->setDisabled(true);
 
@@ -195,17 +185,17 @@ EditDecks::EditDecks(RDStation *station,QWidget *parent,const char *name)
   // Switcher Delay
   //
   edit_swdelay_box=new QSpinBox(this,"edit_swdelay_box");
-  edit_swdelay_box->setGeometry(125,286,40,24);
+  edit_swdelay_box->setGeometry(125,262,40,24);
   edit_swdelay_box->setRange(0,20);
   edit_swdelay_box->setDisabled(true);
   edit_swdelay_label=new QLabel(edit_swdelay_box,tr("Switcher Delay:"),this,
 			     "edit_swdelay_label");
-  edit_swdelay_label->setGeometry(10,286,110,24);
+  edit_swdelay_label->setGeometry(10,262,110,24);
   edit_swdelay_label->setAlignment(AlignRight|AlignVCenter);
   edit_swdelay_label->setDisabled(true);
   edit_swdelay_unit=new QLabel(edit_swdelay_box,tr("1/10 sec"),this,
 			     "edit_swdelay_unit");
-  edit_swdelay_unit->setGeometry(170,286,60,24);
+  edit_swdelay_unit->setGeometry(170,262,60,24);
   edit_swdelay_unit->setAlignment(AlignLeft|AlignVCenter);
   edit_swdelay_unit->setDisabled(true);
   edit_swdelay_box->hide();
@@ -215,45 +205,45 @@ EditDecks::EditDecks(RDStation *station,QWidget *parent,const char *name)
   //
   // Defaults Label
   //
-  label=new QLabel("Defaults",this,"settings_label");
-  label->setGeometry(10,300,100,24);
+  label=new QLabel(tr("Defaults"),this,"settings_label");
+  label->setGeometry(10,276,100,24);
   label->setFont(big_font);
 
   //
   // Default Channels
   //
   edit_channels_box=new QComboBox(this,"edit_channels_box");
-  edit_channels_box->setGeometry(125,324,60,24);
+  edit_channels_box->setGeometry(125,300,60,24);
   edit_channels_box->setInsertionPolicy(QComboBox::NoInsertion);
   label=new QLabel(edit_channels_box,tr("Channels:"),this,
 			     "edit_channels_label");
-  label->setGeometry(10,324,110,24);
+  label->setGeometry(10,300,110,24);
   label->setAlignment(AlignRight|AlignVCenter);
 
   //
   // Default Autotrim Threshold
   //
   edit_threshold_box=new QSpinBox(this,"edit_threshold_box");
-  edit_threshold_box->setGeometry(125,348,70,24);
+  edit_threshold_box->setGeometry(125,324,70,24);
   edit_threshold_box->setSuffix(" dB");
   edit_threshold_box->setRange(-100,0);
   label=new QLabel(edit_threshold_box,tr("Trim Threshold:"),this,
 			     "edit_threshold_label");
-  label->setGeometry(10,348,110,24);
+  label->setGeometry(10,324,110,24);
   label->setAlignment(AlignRight|AlignVCenter);
 
   //
   // Host-Wide Settings Label
   //
-  label=new QLabel("Host-Wide Settings",this,"settings_label");
-  label->setGeometry(10,393,200,24);
+  label=new QLabel(tr("Host-Wide Settings"),this,"settings_label");
+  label->setGeometry(10,369,200,24);
   label->setFont(big_font);
 
   edit_errorrml_edit=new QLineEdit(this,"edit_errorrml_edit");
-  edit_errorrml_edit->setGeometry(125,417,248,24);
+  edit_errorrml_edit->setGeometry(125,393,248,24);
   label=new QLabel(edit_errorrml_edit,tr("Error RML:"),this,
 			     "edit_errorrml_label");
-  label->setGeometry(10,417,110,24);
+  label->setGeometry(10,393,110,24);
   label->setAlignment(AlignRight|AlignVCenter);
 
   //
@@ -305,20 +295,22 @@ EditDecks::EditDecks(RDStation *station,QWidget *parent,const char *name)
   //
   // Populate Data
   //
-  if(edit_station->scanned()) {
-    edit_record_selector->setMaxCards(station->cards());
-    edit_play_selector->setMaxCards(station->cards());
-    edit_audition_selector->setMaxCards(station->cards());
+  if(cae_station->scanned()) {
+    edit_record_selector->setMaxCards(cae_station->cards());
+    edit_play_selector->setMaxCards(cae_station->cards());
+    edit_audition_selector->setMaxCards(cae_station->cards());
     for(int i=0;i<edit_record_selector->maxCards();i++) {
-      edit_record_selector->setMaxPorts(i,station->cardInputs(i));
-      edit_play_selector->setMaxPorts(i,station->cardOutputs(i));
-      edit_audition_selector->setMaxPorts(i,station->cardOutputs(i));
+      edit_record_selector->setMaxPorts(i,cae_station->cardInputs(i));
+      edit_play_selector->setMaxPorts(i,cae_station->cardOutputs(i));
+      edit_audition_selector->setMaxPorts(i,cae_station->cardOutputs(i));
     }
   }
   else {
     QMessageBox::information(this,tr("No Audio Configuration Data"),
-			    tr("Channel assignments will not be available for this host, as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on this host\n(by executing, as user 'root',  the command \"/etc/init.d/rivendell start\")\nin order to populate the audio resources database."));
+			     tr("Channel assignments will not be available for this host as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on the host\nconfigured to run the CAE service in order to populate the audio resources database."));
     edit_record_selector->setDisabled(true);
+    edit_monitor_box->setDisabled(true);
+    edit_monitor_label->setDisabled(true);
     edit_play_selector->setDisabled(true);
     edit_audition_selector->setDisabled(true);
   }
@@ -336,9 +328,6 @@ EditDecks::EditDecks(RDStation *station,QWidget *parent,const char *name)
   edit_format_box->insertItem(tr("MPEG Layer 2"));
   edit_channels_box->insertItem("1");
   edit_channels_box->insertItem("2");
-  edit_samprate_box->insertItem("32000");
-  edit_samprate_box->insertItem("44100");
-  edit_samprate_box->insertItem("48000");
   edit_bitrate_box->insertItem(tr("32 kbps/chan"));
   edit_bitrate_box->insertItem(tr("48 kbps/chan"));
   edit_bitrate_box->insertItem(tr("56 kbps/chan"));
@@ -368,7 +357,6 @@ EditDecks::~EditDecks()
   delete edit_record_deck_box;
   delete edit_format_box;
   delete edit_channels_box;
-  delete edit_samprate_box;
   delete edit_bitrate_box;
   delete edit_threshold_box;
   delete edit_record_selector;
@@ -410,7 +398,7 @@ void EditDecks::playDeckActivatedData(int chan)
 
 void EditDecks::recordCardChangedData(int card)
 {
-  if(card>=0) {
+  if((card>=0)&&edit_monitor_label->isEnabled()) {
     edit_monitor_box->setEnabled(true);
     edit_monitor_box->setMaxValue(edit_station->cardOutputs(card)-1);
     monitorPortChangedData(edit_monitor_box->value());
@@ -583,6 +571,7 @@ void EditDecks::ReadRecord(int chan)
 	  break;
 
 	case RDSettings::MpegL2:
+	case RDSettings::MpegL2Wav:
 	  edit_format_box->setCurrentItem(1);
 	  edit_bitrate_box->setEnabled(true);
 	  break;
@@ -594,17 +583,6 @@ void EditDecks::ReadRecord(int chan)
 	  break;
     }
     edit_channels_box->setCurrentItem(edit_record_deck->defaultChannels()-1);
-    switch(edit_record_deck->defaultSamprate()) {
-	case 32000:
-	  edit_samprate_box->setCurrentItem(0);
-	  break;
-	case 44100:
-	  edit_samprate_box->setCurrentItem(1);
-	  break;
-	case 48000:
-	  edit_samprate_box->setCurrentItem(2);
-	  break;
-    }
     switch(edit_record_deck->defaultBitrate()) {
 	case 32000:
 	  edit_bitrate_box->setCurrentItem(0);
@@ -713,8 +691,6 @@ void EditDecks::WriteRecord(int chan)
 	  break;
     }
     edit_record_deck->setDefaultChannels(edit_channels_box->currentItem()+1);
-    sscanf((const char *)edit_samprate_box->currentText(),"%d",&temp);
-    edit_record_deck->setDefaultSamprate(temp);
     sscanf((const char *)edit_bitrate_box->currentText(),"%d",&temp);
     edit_record_deck->setDefaultBitrate(temp*1000);
     edit_record_deck->setSwitchStation(edit_swstation_box->currentText());
