@@ -2,9 +2,9 @@
 //
 // Edit a Rivendell Workstation
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_station.h,v 1.28 2008-09-18 19:02:11 fredg Exp $
+//      $Id: edit_station.h,v 1.36 2011/10/31 11:38:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -49,10 +49,14 @@ class EditStation : public QDialog
    QSize sizeHint() const;
    QSizePolicy sizePolicy() const;
 
-  private slots:
+ protected:
+  void paintEvent(QPaintEvent *e);
+
+ private slots:
    void selectClicked();
    void heartbeatToggledData(bool state);
    void heartbeatClickedData();
+   void caeStationActivatedData(const QString &station_name);
    void okData();
    void okTimerData();
    void cancelData();
@@ -69,11 +73,13 @@ class EditStation : public QDialog
    void editBackupsData();
    void editDropboxesData();
    void editEncodersData();
+   void jackSettingsData();
 
   private:
    QString DisplayPart(QString);
    QString HostPart(QString);
    RDStation *station_station;
+   RDStation *station_cae_station;
    RDCatchConnect *station_catch_connect;
    QLineEdit *station_name_edit;
    QLineEdit *station_description_edit;
@@ -93,6 +99,9 @@ class EditStation : public QDialog
    QLabel *station_hbinterval_unit;
    QString station_cart_filter;
    QString station_cart_group;
+   QCheckBox *station_maint_box;
+   QComboBox *station_http_station_box;
+   QComboBox *station_cae_station_box;
 };
 
 
