@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: local_macros.cpp,v 1.26.2.2 2009/11/10 22:53:30 cvs Exp $
+//      $Id: local_macros.cpp,v 1.31.6.1 2012/07/23 20:56:20 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -146,7 +146,7 @@ void MainWidget::RunLocalMacros(RDMacro *rml)
 		if((logline=air_log[rml->arg(0).toInt()-1]->logLine(i))!=NULL) {
 		  if(logline->status()==RDLogLine::Scheduled) {
 		    found=true;
-		    continue;
+		    i=air_log[rml->arg(0).toInt()-1]->size();
 		  }
 		}
 	      }
@@ -225,6 +225,41 @@ void MainWidget::RunLocalMacros(RDMacro *rml)
 	}   
 	break;
 
+      case RDMacro::PC:   // Label Button
+	if(rml->argQuantity()!=5) {
+	  if(rml->echoRequested()) {
+	    rml->acknowledge(false);
+	    rdripc->sendRml(rml);
+	  }
+	  return;
+	}
+	if(!GetPanel(rml->arg(0).toString(),&panel_type,&panel_number)) {
+	  if(rml->echoRequested()) {
+	    rml->acknowledge(false);
+	    rdripc->sendRml(rml);
+	  }
+	  return;
+	}
+	if((rml->arg(1).toInt()<=0)||
+	   (rml->arg(1).toInt()>AIR_PANEL_BUTTON_COLUMNS)||
+	   (rml->arg(2).toInt()<=0)||
+	   (rml->arg(2).toInt()>AIR_PANEL_BUTTON_ROWS)) {
+	  if(rml->echoRequested()) {
+	    rml->acknowledge(false);
+	    rdripc->sendRml(rml);
+	  }
+	  return;
+	}
+	air_panel->setText(panel_type,panel_number,rml->arg(2).toInt()-1,
+			   rml->arg(1).toInt()-1,rml->arg(3).toString());
+	air_panel->setColor(panel_type,panel_number,rml->arg(2).toInt()-1,
+			    rml->arg(1).toInt()-1,rml->arg(4).toString());
+	if(rml->echoRequested()) {
+	  rml->acknowledge(true);
+	  rdripc->sendRml(rml);
+	}   
+	break;
+
       case RDMacro::PE:    // Load Panel Button
 	if(rml->argQuantity()!=4) {
 	  if(rml->echoRequested()) {
@@ -826,20 +861,12 @@ void MainWidget::RunLocalMacros(RDMacro *rml)
 
 QFont MainWidget::MessageFont(QString str)
 {
-  QFont font;
-  QFontMetrics *metric;
-  for(int i=26;i>=12;i-=2) {
-    font=QFont("helvetica",i,QFont::Normal);
-    metric=new QFontMetrics(font);
-    if(metric->width(str)<MESSAGE_WIDGET_WIDTH) {
-      delete metric;
-      font.setPixelSize(i);
-      return font;
+  for(int i=(AIR_MESSAGE_FONT_QUANTITY-1);i>=0;i--) {
+    if(air_message_metrics[i]->width(str)<MESSAGE_WIDGET_WIDTH) {
+      return air_message_fonts[i];
     }
   }
-  delete metric;
-  font.setPixelSize(12);
-  return font;
+  return air_message_fonts[0];
 }
 
 
