@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: loglinebox.cpp,v 1.83.2.2 2010/02/08 23:50:14 cvs Exp $
+//      $Id: loglinebox.cpp,v 1.89 2011/05/20 20:46:44 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -45,6 +45,7 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   line_type=RDLogLine::UnknownType;
   line_mode=LogLineBox::Full;
   line_time_mode=RDAirPlayConf::TwentyFourHour;
+  line_logline=NULL;
   log_id=-1;
   log_line=-1;
 
@@ -117,6 +118,72 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   line_transition_palette.setColor(QPalette::Inactive,QColorGroup::Foreground,
 				  QColor(RD_CUSTOM_TRANSITION_COLOR));
 
+  //
+  // Count Up
+  //
+  line_up_label=new QLabel(this,"line_up_label");
+  line_up_label->setGeometry(5,65,65,16);
+  line_up_label->setAlignment(AlignLeft|AlignVCenter);
+  line_up_label->setFont(line_font);
+  line_up_label->hide();
+
+  //
+  // Position Slider
+  //
+  line_position_bar=new QProgressBar(this,"line_position_bar");
+  line_position_bar->setGeometry(75,66,sizeHint().width()-150,13);
+  line_position_bar->setPercentageVisible(false);
+  line_position_bar->hide();
+
+  //
+  // Count Down
+  //
+  line_down_label=new QLabel(this,"line_down_label");
+  line_down_label->setGeometry(sizeHint().width()-72,65,65,16);
+  line_down_label->setAlignment(AlignLeft|AlignVCenter);
+  line_down_label->setFont(line_font);
+  line_down_label->hide();
+
+  //
+  // Cut Description
+  //
+  line_description_label=new QLabel(this,"line_description_label");
+  line_description_label->setGeometry((sizeHint().width()/2),48,(sizeHint().width()/2 -10),16);
+  line_description_label->setFont(line_font);
+  line_description_label->hide();
+
+  //
+  // Outcue
+  //
+  line_outcue_label=new QLabel(this,"line_outcue_label");
+  line_outcue_label->setGeometry(5,48, (sizeHint().width()/2 -10),16);
+  line_outcue_label->setFont(outcue_font);
+  line_outcue_label->hide();
+
+  //
+  // Artist
+  //
+  line_artist_label=new QLabel(this,"line_artist_label");
+  line_artist_label->setGeometry(5,33,sizeHint().width()-10,16);
+  line_artist_label->setFont(line_font);
+
+  //
+  // Title
+  //
+  line_title_label=new QLabel(this,"line_title_label");
+  line_title_label->setGeometry(5,18,sizeHint().width()-10,18);
+  line_title_label->setFont(line_bold_font);
+
+  //
+  // Marker Comment
+  //
+  line_comment_label=new RDLabel(this,"line_comment_label");
+  line_comment_label->setGeometry(5,18,sizeHint().width()-10,62);
+  line_comment_label->setFont(line_font);
+  line_comment_label->setAlignment(AlignTop|AlignLeft);
+  line_comment_label->setWordWrapEnabled(true);
+  line_comment_label->hide();
+
   //
   // Icon
   //
@@ -177,72 +244,6 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   line_trans_label->setAlignment(AlignRight);
   line_trans_label->setFont(line_bold_font);
 
-  //
-  // Title
-  //
-  line_title_label=new QLabel(this,"line_title_label");
-  line_title_label->setGeometry(5,18,sizeHint().width()-10,16);
-  line_title_label->setFont(line_bold_font);
-
-  //
-  // Artist
-  //
-  line_artist_label=new QLabel(this,"line_artist_label");
-  line_artist_label->setGeometry(5,33,sizeHint().width()-10,16);
-  line_artist_label->setFont(line_font);
-
-  //
-  // Outcue
-  //
-  line_outcue_label=new QLabel(this,"line_outcue_label");
-  line_outcue_label->setGeometry(5,48, (sizeHint().width()/2 -10),16);
-  line_outcue_label->setFont(outcue_font);
-  line_outcue_label->hide();
-
-  //
-  // Cut Description
-  //
-  line_description_label=new QLabel(this,"line_description_label");
-  line_description_label->setGeometry((sizeHint().width()/2),48,(sizeHint().width()/2 -10),14);
-  line_description_label->setFont(line_font);
-  line_description_label->hide();
-
-  //
-  // Marker Comment
-  //
-  line_comment_label=new RDLabel(this,"line_comment_label");
-  line_comment_label->setGeometry(5,18,sizeHint().width()-10,62);
-  line_comment_label->setFont(line_font);
-  line_comment_label->setAlignment(AlignTop|AlignLeft);
-  line_comment_label->setWordWrapEnabled(true);
-  line_comment_label->hide();
-
-  //
-  // Count Up
-  //
-  line_up_label=new QLabel(this,"line_up_label");
-  line_up_label->setGeometry(5,65,65,16);
-  line_up_label->setAlignment(AlignLeft|AlignVCenter);
-  line_up_label->setFont(line_font);
-  line_up_label->hide();
-
-  //
-  // Position Slider
-  //
-  line_position_bar=new QProgressBar(this,"line_position_bar");
-  line_position_bar->setGeometry(75,66,sizeHint().width()-150,13);
-  line_position_bar->setPercentageVisible(false);
-  line_position_bar->hide();
-
-  //
-  // Count Down
-  //
-  line_down_label=new QLabel(this,"line_down_label");
-  line_down_label->setGeometry(sizeHint().width()-72,65,65,16);
-  line_down_label->setAlignment(AlignLeft|AlignVCenter);
-  line_down_label->setFont(line_font);
-  line_down_label->hide();
-
   SetColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
 
   //
@@ -401,237 +402,252 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	break;
   }
   switch(line_type) {
-      case RDLogLine::Cart:
-	line_comment_label->hide();
-	cart=new RDCart(logline->cartNumber());
-        cut=new RDCut(QString().sprintf("%06u_%03u",logline->cartNumber(),
-                                        logline->cutNumber()));
-	if(!cart->exists()) {
-	  line_cart_label->
-	    setText(QString().sprintf("%06u",logline->cartNumber()));
-	  line_description_label->clear();
-	  line_artist_label->clear();
-	  line_cut_label->clear();
-	  line_group_label->clear();
-	  line_outcue_label->clear();
-	  line_length_label->setText("00:00");
-	  line_talktime_label->setText(":00");
-	  line_up_label->setText("0:00:00");
-	  line_down_label->setText("0:00:00");
-	  line_comment_label->clear();
-	  line_icon_label->setPixmap(*line_playout_map);
-	  line_title_label->setText(tr("[CART NOT FOUND]"));
-	  SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
-	  delete cart;
-          delete cut;
-	}
-	else {
-	  if(((cart->forcedLength()==0)&&(cart->type()==RDCart::Audio))||
-	     (line_logline->state()==RDLogLine::NoCut)) {
-	    line_cart_label->
-	      setText(QString().sprintf("%06u",logline->cartNumber()));
-	    line_description_label->setText(cut->description());
-	    line_artist_label->setText(tr("[NO AUDIO AVAILABLE]"));
-	    line_cut_label->clear();
-	    line_group_label->clear();
-	    line_outcue_label->clear();
-	    line_length_label->setText("00:00");
-	    line_talktime_label->setText(":00");
-	    line_up_label->setText("0:00:00");
-	    line_down_label->setText("0:00:00");
-	    line_comment_label->clear();
-	    line_icon_label->setPixmap(*line_playout_map);
-	    line_title_label->setText(logline->title());
-	    SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
-	    delete cart;
-            delete cut;
-	  }
-	  else {
-	    line_cart_label->
-	      setText(QString().sprintf("%06u",logline->cartNumber()));
-	    if(line_logline->evergreen()) {
-	      SetColor(QColor(LOGLINEBOX_EVERGREEN_COLOR));
-	    }
-	    else {
-	      SetColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
-	    }
-	    if(line_logline->source()==RDLogLine::Tracker) {
-	      line_icon_label->setPixmap(*line_track_cart_map);
-	    }
-	    else {
-	      line_icon_label->setPixmap(*line_playout_map);
-	    }
-	    line_group_label->setText(cart->groupName());
-	    p=line_group_label->palette();
-	    p.setColor(QColorGroup::Foreground,line_logline->groupColor());
-	    line_group_label->setPalette(p);
-	    if(line_logline->talkLength()<=0) {
-	      line_talktime_label->setText(":00");
-	    }
-	    else {
-	      line_talktime_label->
-		setText(RDGetTimeLength(line_logline->talkLength(),
-				       false,false));
-	    }
-	    line_length_label->
-	      setText(RDGetTimeLength(line_logline->effectiveLength(),
-				     false,false));
-	    if(line_logline->timescalingActive()) {
-	      line_length_label->setPalette(line_hard_palette);
-	    }
-	    else {
-	      line_length_label->setPalette(line_time_palette);
-	    }
-	    if(line_logline->originUser().isEmpty()||
-	       (!line_logline->originDateTime().isValid())) {
-	      line_title_label->setText(line_logline->title());
-	    }
-	    else {
-	      line_title_label->setText(QString().
-				sprintf("%s -- %s %s",
-				 (const char *)line_logline->title(),
-				 (const char *)line_logline->originUser(),
-				 (const char *)line_logline->originDateTime().
-				 toString("M/d hh:mm")));
-	    }
-	    line_description_label->setText(cut->description());
-	    line_artist_label->setText(cart->artist());
-	    line_up_label->
-	      setText(RDGetTimeLength(line_logline->playPosition(),true,true));
-	    line_down_label->
-	      setText(RDGetTimeLength(line_logline->effectiveLength()-
-				     line_logline->playPosition(),true,true));
-	    line_position_bar->setTotalSteps(line_logline->effectiveLength());
-	    line_position_bar->setProgress(line_logline->playPosition());
-	    if(logline->cutNumber()>=0) {
-	      line_cut_label->
-		setText(QString().sprintf("%03u",logline->cutNumber()));
-	      line_outcue_label->setText(logline->outcue());
-	    }
-	    else {
-	      SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
-	      line_cut_label->clear();
-	      line_outcue_label->setText(tr("[NO VALID CUT AVAILABLE]"));
-	    }
-	    delete cart;
-	    delete cut;
-	    setMode(line_mode);
-	    line_title_label->show();
-	    line_artist_label->show();
-	  }
-	}
+  case RDLogLine::Cart:
+    line_comment_label->hide();
+    cart=new RDCart(logline->cartNumber());
+    cut=new RDCut(QString().sprintf("%06u_%03u",logline->cartNumber(),
+				    logline->cutNumber()));
+    if(!cart->exists()) {
+      line_cart_label->
+	setText(QString().sprintf("%06u",logline->cartNumber()));
+      line_description_label->clear();
+      line_artist_label->clear();
+      line_cut_label->clear();
+      line_group_label->clear();
+      line_outcue_label->clear();
+      line_length_label->setText("00:00");
+      line_talktime_label->setText(":00");
+      line_up_label->setText("0:00:00");
+      line_down_label->setText("0:00:00");
+      line_comment_label->clear();
+      line_title_label->setText(tr("[CART NOT FOUND]"));
+      switch(cart->type()) {
+      case RDCart::Audio:
+      case RDCart::Macro:
+      case RDCart::All:
+	line_icon_label->setPixmap(*line_playout_map);
 	break;
-
-      case RDLogLine::Marker:
-	line_icon_label->setPixmap(*line_notemarker_map);
-	SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
-	line_title_label->hide();
-	line_description_label->hide();
-	line_artist_label->hide();
-	line_cart_label->setText(tr("MARKER"));
-	line_group_label->setText(logline->markerLabel());
-	line_length_label->setText(":00");
-	line_transition=logline->transType();
-	line_comment_label->setText(logline->markerComment());
-	setMode(line_mode);
-	line_comment_label->show();
-	break;
-
-      case RDLogLine::Track:
-	line_icon_label->setPixmap(*line_mic16_map);
-	SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
-	line_title_label->hide();
-	line_description_label->hide();
-	line_artist_label->hide();
-	line_cart_label->setText(tr("TRACK"));
-	line_group_label->setText("");
-	line_length_label->setText(":00");
-	line_transition=logline->transType();
-	line_comment_label->setText(logline->markerComment());
-	setMode(line_mode);
-	line_comment_label->show();
-	break;
-
-      case RDLogLine::MusicLink:
-	line_icon_label->setPixmap(*line_music_map);
-	SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
-	line_title_label->hide();
-	line_description_label->hide();
-	line_artist_label->hide();
-	line_cart_label->setText(tr("LINK"));
-	line_group_label->setText("");
-	line_length_label->setText(":00");
-	line_transition=logline->transType();
-	line_comment_label->setText(tr("[music import]"));
-	setMode(line_mode);
-	line_comment_label->show();
-	break;
-
-      case RDLogLine::TrafficLink:
-	line_icon_label->setPixmap(*line_traffic_map);
-	SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
-	line_title_label->hide();
-	line_description_label->hide();
-	line_artist_label->hide();
-	line_cart_label->setText(tr("LINK"));
-	line_group_label->setText("");
-	line_length_label->setText(":00");
-	line_transition=logline->transType();
-	line_comment_label->setText(tr("[traffic import]"));
-	setMode(line_mode);
-	line_comment_label->show();
-	break;
-
-      case RDLogLine::Chain:
-	line_icon_label->setPixmap(*line_chain_map);
-	SetColor(QColor(LOGLINEBOX_CHAIN_COLOR));
-	line_title_label->setText(logline->markerLabel());
-	line_description_label->setText("");
-	line_artist_label->setText(logline->markerComment());
-	line_cart_label->setText(tr("CHAIN"));
-	line_group_label->setText("");
-	line_length_label->setText(":00");
-	line_transition=logline->transType();
-	line_comment_label->hide();
-	setMode(line_mode);
-	line_title_label->show();
-	line_artist_label->show();
-	break;
-
-      case RDLogLine::Macro:
-	line_icon_label->setPixmap(*line_macro_map);
-	line_comment_label->hide();
-	cart=new RDCart(logline->cartNumber());
-        cut=new RDCut(QString().sprintf("%06u_%03u",logline->cartNumber(),
-                                        logline->cutNumber()));
-	if(!cart->exists()) {
-	  SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
+      }
+      SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
+      delete cart;
+      delete cut;
+    }
+    else {
+      if(((cart->forcedLength()==0)&&(cart->type()==RDCart::Audio))||
+	 (line_logline->state()==RDLogLine::NoCut)) {
+	line_cart_label->
+	  setText(QString().sprintf("%06u",logline->cartNumber()));
+	line_description_label->setText(cut->description());
+	line_artist_label->setText(tr("[NO AUDIO AVAILABLE]"));
+	line_cut_label->clear();
+	line_group_label->clear();
+	line_outcue_label->clear();
+	line_length_label->setText("00:00");
+	line_talktime_label->setText(":00");
+	line_up_label->setText("0:00:00");
+	line_down_label->setText("0:00:00");
+	line_comment_label->clear();
+	line_icon_label->setPixmap(*line_playout_map);
+	line_title_label->setText(logline->title());
+	SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
+	delete cart;
+	delete cut;
+      }
+      else {
+	line_cart_label->
+	  setText(QString().sprintf("%06u",logline->cartNumber()));
+	if(line_logline->evergreen()) {
+	  SetColor(QColor(LOGLINEBOX_EVERGREEN_COLOR));
 	}
 	else {
 	  SetColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
 	}
-	line_cart_label->setText(QString().sprintf("%06u",cart->number()));
-	line_cut_label->setText("");
+	if(line_logline->source()==RDLogLine::Tracker) {
+	  line_icon_label->setPixmap(*line_track_cart_map);
+	}
+	else {
+	  switch(cart->type()) {
+	  case RDCart::Audio:
+	  case RDCart::All:
+	    line_icon_label->setPixmap(*line_playout_map);
+	    break;
+	    
+	  case RDCart::Macro:
+	    line_icon_label->setPixmap(*line_macro_map);
+	    break;
+	  }
+	}
 	line_group_label->setText(cart->groupName());
 	p=line_group_label->palette();
 	p.setColor(QColorGroup::Foreground,line_logline->groupColor());
 	line_group_label->setPalette(p);
+	if(line_logline->talkLength()<=0) {
+	  line_talktime_label->setText(":00");
+	}
+	else {
+	  line_talktime_label->
+	    setText(RDGetTimeLength(line_logline->talkLength(),
+				    false,false));
+	}
 	line_length_label->
 	  setText(RDGetTimeLength(line_logline->effectiveLength(),
 				  false,false));
-	line_title_label->setText(cart->title());
-	line_description_label->setText("");
+	if(line_logline->timescalingActive()) {
+	  line_length_label->setPalette(line_hard_palette);
+	}
+	else {
+	  line_length_label->setPalette(line_time_palette);
+	}
+	if(line_logline->originUser().isEmpty()||
+	   (!line_logline->originDateTime().isValid())) {
+	  line_title_label->setText(line_logline->title());
+	}
+	else {
+	  line_title_label->setText(QString().
+				    sprintf("%s -- %s %s",
+					    (const char *)line_logline->title(),
+					    (const char *)line_logline->originUser(),
+					    (const char *)line_logline->originDateTime().
+					    toString("M/d hh:mm")));
+	}
+	line_description_label->setText(cut->description());
 	line_artist_label->setText(cart->artist());
-	line_outcue_label->setText("");
+	line_up_label->
+	  setText(RDGetTimeLength(line_logline->playPosition(),true,true));
+	line_down_label->
+	  setText(RDGetTimeLength(line_logline->effectiveLength()-
+				  line_logline->playPosition(),true,true));
+	line_position_bar->setTotalSteps(line_logline->effectiveLength());
+	line_position_bar->setProgress(line_logline->playPosition());
+	if(logline->cutNumber()>=0) {
+	  line_cut_label->
+	    setText(QString().sprintf("%03u",logline->cutNumber()));
+	  line_outcue_label->setText(logline->outcue());
+	}
+	else {
+	  SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
+	  line_cut_label->clear();
+	  line_outcue_label->setText(tr("[NO VALID CUT AVAILABLE]"));
+	}
 	delete cart;
 	delete cut;
 	setMode(line_mode);
 	line_title_label->show();
 	line_artist_label->show();
-	break;
+      }
+    }
+    break;
+    
+  case RDLogLine::Marker:
+    line_icon_label->setPixmap(*line_notemarker_map);
+    SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
+    line_title_label->hide();
+    line_description_label->hide();
+    line_artist_label->hide();
+    line_cart_label->setText(tr("MARKER"));
+    line_group_label->setText(logline->markerLabel());
+    line_length_label->setText(":00");
+    line_transition=logline->transType();
+    line_comment_label->setText(logline->markerComment());
+    setMode(line_mode);
+    line_comment_label->show();
+    break;
+    
+  case RDLogLine::Track:
+    line_icon_label->setPixmap(*line_mic16_map);
+    SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
+    line_title_label->hide();
+    line_description_label->hide();
+    line_artist_label->hide();
+    line_cart_label->setText(tr("TRACK"));
+    line_group_label->setText("");
+    line_length_label->setText(":00");
+    line_transition=logline->transType();
+    line_comment_label->setText(logline->markerComment());
+    setMode(line_mode);
+    line_comment_label->show();
+    break;
+    
+  case RDLogLine::MusicLink:
+    line_icon_label->setPixmap(*line_music_map);
+    SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
+    line_title_label->hide();
+    line_description_label->hide();
+    line_artist_label->hide();
+    line_cart_label->setText(tr("LINK"));
+    line_group_label->setText("");
+    line_length_label->setText(":00");
+    line_transition=logline->transType();
+    line_comment_label->setText(tr("[music import]"));
+    setMode(line_mode);
+    line_comment_label->show();
+    break;
+    
+  case RDLogLine::TrafficLink:
+    line_icon_label->setPixmap(*line_traffic_map);
+    SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
+    line_title_label->hide();
+    line_description_label->hide();
+    line_artist_label->hide();
+    line_cart_label->setText(tr("LINK"));
+    line_group_label->setText("");
+    line_length_label->setText(":00");
+    line_transition=logline->transType();
+    line_comment_label->setText(tr("[traffic import]"));
+    setMode(line_mode);
+    line_comment_label->show();
+    break;
 
-      default:
-	break;
+  case RDLogLine::Chain:
+    line_icon_label->setPixmap(*line_chain_map);
+    SetColor(QColor(LOGLINEBOX_CHAIN_COLOR));
+    line_title_label->setText(logline->markerLabel());
+    line_description_label->setText("");
+    line_artist_label->setText(logline->markerComment());
+    line_cart_label->setText(tr("CHAIN"));
+    line_group_label->setText("");
+    line_length_label->setText(":00");
+    line_transition=logline->transType();
+    line_comment_label->hide();
+    setMode(line_mode);
+    line_title_label->show();
+    line_artist_label->show();
+    break;
+
+  case RDLogLine::Macro:
+    line_icon_label->setPixmap(*line_macro_map);
+    line_comment_label->hide();
+    cart=new RDCart(logline->cartNumber());
+    cut=new RDCut(QString().sprintf("%06u_%03u",logline->cartNumber(),
+				    logline->cutNumber()));
+    if(!cart->exists()) {
+      SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
+    }
+    else {
+      SetColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
+    }
+    line_cart_label->setText(QString().sprintf("%06u",cart->number()));
+    line_cut_label->setText("");
+    line_group_label->setText(cart->groupName());
+    p=line_group_label->palette();
+    p.setColor(QColorGroup::Foreground,line_logline->groupColor());
+    line_group_label->setPalette(p);
+    line_length_label->
+      setText(RDGetTimeLength(line_logline->effectiveLength(),
+			      false,false));
+    line_title_label->setText(cart->title());
+    line_description_label->setText("");
+    line_artist_label->setText(cart->artist());
+    line_outcue_label->setText("");
+    delete cart;
+    delete cut;
+    setMode(line_mode);
+    line_title_label->show();
+    line_artist_label->show();
+    break;
+
+  default:
+    break;
   }
   PrintTime();
 }
