@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_cartevent.h,v 1.8 2007/02/14 21:53:27 fredg Exp $
+//      $Id: edit_cartevent.h,v 1.11 2010/07/29 19:32:36 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -42,8 +42,8 @@ class EditCartEvent : public QDialog
 {
  Q_OBJECT
  public:
- EditCartEvent(int id,std::vector<int> *adds,QString *filter=0,
-	       QString *group=0,QWidget *parent=0,const char *name=0);
+ EditCartEvent(int id,std::vector<int> *adds,
+	       QWidget *parent=0,const char *name=0);
  ~EditCartEvent();
  QSize sizeHint() const;
  QSizePolicy sizePolicy() const;
@@ -79,8 +79,6 @@ class EditCartEvent : public QDialog
   QCheckBox *edit_fri_button;
   QCheckBox *edit_sat_button;
   QCheckBox *edit_oneshot_box;
-  QString *edit_filter;
-  QString *edit_group;
   std::vector<int> *edit_added_events;
 };
 
