@@ -169,15 +169,15 @@ Audio</translation>
     </message>
     <message>
         <source>RDLibrary</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLibrary</translation>
     </message>
     <message>
         <source>Unable to delete audio!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡No se pudo eliminar el audio!</translation>
     </message>
     <message>
         <source>No audio is present in the cut!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡No hay audios en este cut!</translation>
     </message>
 </context>
 <context>
@@ -280,11 +280,11 @@ Do you still want to proceed?</source>
     </message>
     <message>
         <source>Rip Complete</source>
-        <translation type="unfinished">Lectura completada</translation>
+        <translation>Lectura completada</translation>
     </message>
     <message>
         <source>Rip complete!</source>
-        <translation type="unfinished">¡Lectura completada!</translation>
+        <translation>¡Lectura completada!</translation>
     </message>
     <message>
         <source>Rip Aborted</source>
@@ -316,20 +316,21 @@ Do you want to proceed?</source>
     </message>
     <message>
         <source>RDLibrary - Importer Error</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLibrary - Error al importar</translation>
     </message>
     <message>
         <source>RDLibrary - Ripper Error</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLibrary - Error al leer</translation>
     </message>
     <message>
         <source>Abort
 Rip</source>
-        <translation type="unfinished"></translation>
+        <translation>Abortar
+Lectura</translation>
     </message>
     <message>
         <source>Rip Track</source>
-        <translation type="unfinished"></translation>
+        <translation>Leyendo pista</translation>
     </message>
 </context>
 <context>
@@ -480,7 +481,7 @@ Por favor, chequee la configuración e intente de nuevo.</translation>
     </message>
     <message>
         <source>Total Progress</source>
-        <translation type="unfinished">Progreso total</translation>
+        <translation>Progreso total</translation>
     </message>
     <message>
         <source>No Access</source>
@@ -520,25 +521,28 @@ disco</translation>
     </message>
     <message>
         <source>RDLibrary - Importer Error</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLIbrary - Error al importar</translation>
     </message>
     <message>
         <source>RDLibrary - Ripper Error</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLibrary - Error de lectura</translation>
     </message>
     <message>
         <source>Abort
 Rip</source>
-        <translation type="unfinished"></translation>
+        <translation>Abortar
+Lectura</translation>
     </message>
     <message>
         <source>Rip
 Disk</source>
-        <translation type="unfinished"></translation>
+        <translation>Leer
+Disco</translation>
     </message>
     <message>
         <source>Rip aborted!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡Lectura
+Abortada!</translation>
     </message>
 </context>
 <context>
@@ -601,7 +605,7 @@ Disk</source>
     </message>
     <message>
         <source>Schedule Cuts:</source>
-        <translation>Audios programados:</translation>
+        <translation type="obsolete">Audios programad.:</translation>
     </message>
     <message>
         <source>&amp;Edit
@@ -635,11 +639,11 @@ Script</translation>
     </message>
     <message>
         <source>Sequentially</source>
-        <translation>Secuencial</translation>
+        <translation type="obsolete">Secuencial</translation>
     </message>
     <message>
         <source>Randomly</source>
-        <translation>Aleatorio</translation>
+        <translation type="obsolete">Aleatorio</translation>
     </message>
     <message>
         <source>Missing Title</source>
@@ -689,7 +693,7 @@ los límites del sistema.  ¿Desea continuar?</translation>
     </message>
     <message>
         <source>Scheduler Codes</source>
-        <translation>Códigos del programador</translation>
+        <translation>Códigos musicalizador</translation>
     </message>
     <message>
         <source></source>
@@ -725,6 +729,52 @@ Notas</translation>
         <translation>&amp;Cancelar</translation>
     </message>
 </context>
+<context>
+    <name>EditNotes</name>
+    <message>
+        <source>Notes for cart</source>
+        <translation>Notas para el cartucho</translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation>Acepta&amp;r</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation>&amp;Cancelar</translation>
+    </message>
+</context>
+<context>
+    <name>EditSchedulerCodes</name>
+    <message>
+        <source>Select Scheduler Codes</source>
+        <translation>Elija Códigos para Musicalizar</translation>
+    </message>
+    <message>
+        <source>Available Codes</source>
+        <translation>Códigos disponibles</translation>
+    </message>
+    <message>
+        <source>Assigned Codes</source>
+        <translation>Códigos Asignados</translation>
+    </message>
+    <message>
+        <source>ASSIGN to Carts</source>
+        <translation>ASIGNAR a cartuchos</translation>
+    </message>
+    <message>
+        <source>REMOVE from Carts</source>
+        <translation>REMOVER de Cartuchos</translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation>Acepta&amp;r</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation>&amp;Cancelar</translation>
+    </message>
+</context>
 <context>
     <name>Filter</name>
     <message>
@@ -748,6 +798,41 @@ Notas</translation>
         <translation>&amp;Filtro:</translation>
     </message>
 </context>
+<context>
+    <name>ListReports</name>
+    <message>
+        <source>RDLibrary Reports</source>
+        <translation>Reportes de RDLibrary</translation>
+    </message>
+    <message>
+        <source>Cart Report</source>
+        <translation>Reporte de Cartuchos</translation>
+    </message>
+    <message>
+        <source>Cut Report</source>
+        <translation>Reporte de Audios</translation>
+    </message>
+    <message>
+        <source>Cart Data Dump</source>
+        <translation>Vaciado de datos de Cartuchos</translation>
+    </message>
+    <message>
+        <source>Type:</source>
+        <translation>Tipo:</translation>
+    </message>
+    <message>
+        <source>&amp;Generate</source>
+        <translation>&amp;Generar</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation>&amp;Cerrar</translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished">TODAS</translation>
+    </message>
+</context>
 <context>
     <name>MacroCart</name>
     <message>
@@ -907,7 +992,7 @@ Cartucho</translation>
     </message>
     <message>
         <source>ALL</source>
-        <translation></translation>
+        <translation>TODAS</translation>
     </message>
     <message>
         <source>Empty Clipboard</source>
@@ -953,7 +1038,7 @@ CD</translation>
     </message>
     <message>
         <source>Scheduler Code:</source>
-        <translation>Códs. Program.:</translation>
+        <translation>Códs. Musicaliz.:</translation>
     </message>
     <message>
         <source></source>
@@ -981,7 +1066,7 @@ Do you still want to delete it?</source>
     </message>
     <message>
         <source>rdlibrary : </source>
-        <translation></translation>
+        <translation>rdlibrary : </translation>
     </message>
     <message>
         <source>&amp;Search</source>
@@ -993,23 +1078,23 @@ Do you still want to delete it?</source>
     </message>
     <message>
         <source>Show Note Bubbles</source>
-        <translation>Mostrar Notas Flotantes</translation>
+        <translation>Most. notas flotantes</translation>
     </message>
     <message>
         <source>RDLibrary</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLibrary</translation>
     </message>
     <message>
         <source>Unable to delete audio!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡No puedo eliminar el audio!</translation>
     </message>
     <message>
         <source>Show Only First </source>
-        <translation type="unfinished"></translation>
+        <translation>Mostrar sólo primeros </translation>
     </message>
     <message>
         <source> Matches</source>
-        <translation type="unfinished"></translation>
+        <translation> hallazgos</translation>
     </message>
 </context>
 <context>
@@ -1068,7 +1153,7 @@ Do you still want to delete it?</source>
     </message>
     <message>
         <source>Daypart</source>
-        <translation></translation>
+        <translation>Daypart</translation>
     </message>
     <message>
         <source>&amp;Start Time</source>
@@ -1112,7 +1197,7 @@ Do you still want to delete it?</source>
     </message>
     <message>
         <source>NO SYNC!</source>
-        <translation>¡NO SINC.!</translation>
+        <translation type="obsolete">¡NO SINC.!</translation>
     </message>
     <message>
         <source>Channels</source>
@@ -1242,6 +1327,10 @@ Do you still want to save?</source>
     </message>
     <message>
         <source>&amp;ISCI Code</source>
+        <translation>Código &amp;ISCI</translation>
+    </message>
+    <message>
+        <source>AES ALARM</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
