@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogedit.cpp,v 1.68.2.1 2009/02/12 14:21:26 cvs Exp $
+//      $Id: rdlogedit.cpp,v 1.77 2011/10/17 20:08:21 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -52,8 +52,7 @@
 #include <rddb.h>
 #include <rdtextfile.h>
 #include <rdmixer.h>
-
-
+#include <dbversion.h>
 
 #include <rdlogedit.h>
 #include <edit_log.h>
@@ -80,6 +79,7 @@ RDUser *rduser;
 RDRipc *rdripc;
 RDConfig *log_config;
 RDLogeditConf *rdlogedit_conf;
+RDSystem *rdsystem;
 RDCartDialog *log_cart_dialog;
 bool import_running=false;
 #ifndef WIN32
@@ -110,18 +110,18 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   QString str1;
   QString str2;
   log_log_list=NULL;
-
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-#ifndef WIN32
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-#endif  // WIN32
+  bool skip_db_check=false;
+  unsigned schema=0;
 
   //
   // Read Command Options
   //
   RDCmdSwitch *cmd=new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdlogedit","\n");
+  for(unsigned i=0;i<cmd->keys();i++) {
+    if(cmd->key(i)=="--skip-db-check") {
+      skip_db_check=true;
+    }
+  }
   delete cmd;
 
   //
@@ -153,25 +153,36 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   // Open Database
   //
   QString err;
-  log_db=RDInitDb(&err);
+  log_db=RDInitDb(&schema,&err);
   if(!log_db) {
     QMessageBox::warning(this,tr("Can't Connect"),err);
     exit(0);
   }
-
-  //
-  // CAE Connection
-  //
-#ifndef WIN32
-  rdcae=new RDCae(parent,name);
-  rdcae->connectHost("localhost",CAED_TCP_PORT,log_config->password());
+  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
+#ifdef WIN32
+	    QMessageBox::warning(this,tr("RDLogEdit -- Database Skew"),
+				 tr("This version of RDLogEdit is incompatible with the version installed on the server.\nSee your system administrator for an update!"));
+#else
+    fprintf(stderr,
+	    "rdlogedit: database version mismatch, should be %u, is %u\n",
+	    RD_VERSION_DATABASE,schema);
 #endif  // WIN32
+    exit(256);
+  }
 
   //
   // Allocate Global Resources
   //
   rdstation_conf=new RDStation(log_config->stationName());
 
+  //
+  // CAE Connection
+  //
+#ifndef WIN32
+  rdcae=new RDCae(rdstation_conf,log_config,parent,name);
+  rdcae->connectHost();
+#endif  // WIN32
+
   //
   // RIPC Connection
   //
@@ -184,6 +195,11 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   rdripc=NULL;
 #endif  // WIN32
 
+  //
+  // System Configuration
+  //
+  rdsystem=new RDSystem();
+
   //
   // RDLogEdit Configuration
   //
@@ -193,11 +209,15 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   // Cart Picker
   //
 #ifdef WIN32
-  log_cart_dialog=new RDCartDialog(&log_filter,&log_group,-1,-1,0,0,
-				   NULL,NULL,NULL,"",
+  log_cart_dialog=new RDCartDialog(&log_filter,&log_group,&log_schedcode,
+				   rdlogedit_conf->outputCard(),
+				   rdlogedit_conf->outputPort(),
+				   rdlogedit_conf->startCart(),
+				   rdlogedit_conf->endCart(),
+				   NULL,NULL,rdstation_conf,"",
 				   this,"log_cart_dialog");
 #else
-  log_cart_dialog=new RDCartDialog(&log_filter,&log_group,
+  log_cart_dialog=new RDCartDialog(&log_filter,&log_group,&log_schedcode,
 				   rdlogedit_conf->outputCard(),
 				   rdlogedit_conf->outputPort(),
 				   rdlogedit_conf->startCart(),
@@ -415,7 +435,11 @@ void MainWidget::addData()
                            SERVICE=\"%s\"",
 			  (const char *)logname,
 			  (const char *)logname,
+#ifdef WIN32
+			  RD_USER_LOGIN_NAME,
+#else
 			  (const char *)rdripc->user(),
+#endif  // WIN32
 			  (const char *)svcname);
     q=new RDSqlQuery(sql);
     if(!q->isActive()) {
@@ -496,7 +520,12 @@ void MainWidget::deleteData()
 	return;
       }
     }
-    log->remove();
+    if(!log->remove(rdstation_conf,rduser)) {
+      QMessageBox::warning(this,tr("RDLogEdit"),
+			   tr("Unable to delete log, audio deletion error!"));
+      delete log;
+      return;
+    }
     delete log;
     delete item;
   }
