@@ -11,7 +11,7 @@
     </message>
     <message>
         <source>Log C&amp;hain</source>
-        <translation>Enca&amp;denar a playlist</translation>
+        <translation>Enca&amp;denar a Lista</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
@@ -30,7 +30,7 @@
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Iniciar en:</translation>
+        <translation>Inicia en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
@@ -46,7 +46,7 @@
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esperar hasta</translation>
+        <translation>Espe. hasta</translation>
     </message>
     <message>
         <source>Play</source>
@@ -58,7 +58,7 @@
     </message>
     <message>
         <source>Stop</source>
-        <translation>Detener</translation>
+        <translation>Parar</translation>
     </message>
     <message>
         <source>Transition Type:</source>
@@ -66,7 +66,7 @@
     </message>
     <message>
         <source>Log Name</source>
-        <translation>Nombre del playlist</translation>
+        <translation>Nombre de la Lista</translation>
     </message>
     <message>
         <source>Select</source>
@@ -86,14 +86,14 @@
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transición si el cartucho previo termina antes</translation>
+        <translation>Transic. si cart. previo termina antes de</translation>
     </message>
 </context>
 <context>
     <name>EditLog</name>
     <message>
         <source>Edit Log</source>
-        <translation>Editar playlist</translation>
+        <translation>Editar Lista</translation>
     </message>
     <message>
         <source>Log Name:</source>
@@ -101,7 +101,7 @@
     </message>
     <message>
         <source>Origin:</source>
-        <translation>Origen:</translation>
+        <translation>Por:</translation>
     </message>
     <message>
         <source>Description:</source>
@@ -205,7 +205,7 @@ Meta</translation>
     </message>
     <message>
         <source>Paste</source>
-        <translation></translation>
+        <translation>Pegar</translation>
     </message>
     <message>
         <source>&amp;Save</source>
@@ -232,26 +232,26 @@ Meta</translation>
     <message>
         <source>This log contains one or more carts
 that are invalid for the selected service!</source>
-        <translation>¡Este playlist contiene uno o más cartuchos
+        <translation>¡Esta Lista contiene uno o más cartuchos
 que son inválidos para el dispositivo elegido!</translation>
     </message>
     <message>
         <source>The log contains carts that are disabled
 for the selected service!</source>
-        <translation>¡El playlist contiene cartuchos que están
+        <translation>¡La Lista contiene cartuchos que están
 desactivados para el dispositivo seleccionado!</translation>
     </message>
     <message>
         <source>Add Log</source>
-        <translation>Agregar playlist</translation>
+        <translation>Agregar Lista</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>El playlist existe</translation>
+        <translation>La Lista ya existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>¡El playlist ya existe!</translation>
+        <translation>¡El playlist o Lista ya existe!</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
@@ -260,7 +260,7 @@ desactivados para el dispositivo seleccionado!</translation>
     <message>
         <source>The log has been modified.
 Do you want to save your changes?</source>
-        <translation>El playlist ha sido modificado.
+        <translation>La Lista ha sido modificada.
 ¿Desea guardar los cambios?</translation>
     </message>
     <message>
@@ -269,7 +269,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>STOP</source>
-        <translation>DETENER</translation>
+        <translation>PARAR</translation>
     </message>
     <message>
         <source>SEGUE</source>
@@ -285,11 +285,11 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>LOG CHAIN</source>
-        <translation>ENCADENAR A PLAYLIST</translation>
+        <translation>ENCADENAR A LISTA</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
-        <translation>--- fin de playlist ---</translation>
+        <translation>--- fin de lista ---</translation>
     </message>
     <message>
         <source>SOURCE</source>
@@ -317,7 +317,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>Voice Tracker</source>
-        <translation></translation>
+        <translation>Pista de voz</translation>
     </message>
     <message>
         <source>Tracks:</source>
@@ -344,7 +344,7 @@ Do you want to save your changes?</source>
 for the selected service!
 
 Do you still want to save?</source>
-        <translation>¡El playlist contiene cartuchos que están 
+        <translation>¡La Lista contiene cartuchos que están 
 desactivados para el servicio actual!
 
 ¿Aún así desea guardarlo?</translation>
@@ -371,15 +371,15 @@ desactivados para el servicio actual!
     </message>
     <message>
         <source>Next Stop:</source>
-        <translation>Próxima parada:</translation>
+        <translation>Próx.parad:</translation>
     </message>
     <message>
         <source>Log End:</source>
-        <translation>Fin del playlist:</translation>
+        <translation>Fin Lista:</translation>
     </message>
     <message>
         <source>Run Length</source>
-        <translation>Duración total</translation>
+        <translation>Durac. total</translation>
     </message>
     <message>
         <source>Selected:</source>
@@ -395,7 +395,7 @@ desactivados para el servicio actual!
     </message>
     <message>
         <source>Unable to save log, audio deletion error!</source>
-        <translation type="unfinished"></translation>
+        <translation>No es posible guardar la Lista, ¡error por eliminación de audio!</translation>
     </message>
 </context>
 <context>
@@ -406,7 +406,7 @@ desactivados para el servicio actual!
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Iniciar en:</translation>
+        <translation>Inicia en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
@@ -422,7 +422,7 @@ desactivados para el servicio actual!
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esperar hasta</translation>
+        <translation>Esp. hasta</translation>
     </message>
     <message>
         <source>Play</source>
@@ -434,7 +434,7 @@ desactivados para el servicio actual!
     </message>
     <message>
         <source>Stop</source>
-        <translation>Detener</translation>
+        <translation>Parar</translation>
     </message>
     <message>
         <source>Transition Type:</source>
@@ -468,7 +468,7 @@ cartucho</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transición si el cartucho previo termina antes</translation>
+        <translation>Transic. si cart. previo termina antes de</translation>
     </message>
     <message>
         <source>Missing Cart</source>
@@ -494,11 +494,11 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Duplicate Start Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Tiempo de inicio duplicado</translation>
     </message>
     <message>
         <source>An event is already scheduled with this start time!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡Se programó un evento para esta misma hora de inicio!</translation>
     </message>
 </context>
 <context>
@@ -509,7 +509,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Iniciar en:</translation>
+        <translation>Inicia en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
@@ -525,7 +525,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esperar hasta</translation>
+        <translation>Esp. hasta</translation>
     </message>
     <message>
         <source>Play</source>
@@ -537,7 +537,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Detener</translation>
+        <translation>Parar</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -557,7 +557,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transición si el cartucho previo termina antes</translation>
+        <translation>Transic. si cart. previo termina antes de</translation>
     </message>
     <message>
         <source>Transition Type:</source>
@@ -572,7 +572,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Iniciar en:</translation>
+        <translation>Inicia en:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
@@ -588,7 +588,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esperar hasta</translation>
+        <translation>Esp. hasta</translation>
     </message>
     <message>
         <source>Play</source>
@@ -600,7 +600,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Detener</translation>
+        <translation>Parar</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -616,7 +616,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transición si el cartucho previo termina antes</translation>
+        <translation>Transic. si cart. previo termina antes de</translation>
     </message>
     <message>
         <source>Transition Type:</source>
@@ -627,7 +627,7 @@ desactivado para el servicio especificado!</translation>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Seleccione un playlist</translation>
+        <translation>Seleccione una Lista</translation>
     </message>
     <message>
         <source>NAME</source>
@@ -658,7 +658,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Log Listing</source>
-        <translation>Lista de Playlists</translation>
+        <translation>Listas de reproducción</translation>
     </message>
     <message>
         <source>Log Exception Report</source>
@@ -678,7 +678,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Log Check</source>
-        <translation>Chequear playlist</translation>
+        <translation>Chequear Listas</translation>
     </message>
     <message>
         <source>No exceptions found.</source>
@@ -713,7 +713,7 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>LOG NAME</source>
-        <translation>NOMBRE DEL PLAYLIST</translation>
+        <translation>NOMBRE DE LA LISTA</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
@@ -757,15 +757,15 @@ desactivado para el servicio especificado!</translation>
     </message>
     <message>
         <source>Add Log</source>
-        <translation>Agregar playlist</translation>
+        <translation>Agregar lista</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>El playlist existe</translation>
+        <translation>La Lista ya existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>¡El playlist ya existe!</translation>
+        <translation>¡La lista de reproducción ya existe!</translation>
     </message>
     <message>
         <source>Always</source>
@@ -796,12 +796,12 @@ Continue?</source>
     <message>
         <source>Voice
 &amp;Tracker</source>
-        <translation>Voice
-&amp;Tracker</translation>
+        <translation>Pistas
+de &amp;Voz</translation>
     </message>
     <message>
         <source>Delete Log</source>
-        <translation>Eliminar playlist</translation>
+        <translation>Eliminar Lista</translation>
     </message>
     <message>
         <source>MUSIC</source>
@@ -827,15 +827,243 @@ Continue?</source>
         <source>Log
 Report</source>
         <translation>Reporte
-de PlayList</translation>
+de Listas</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>Unable to delete log, audio deletion error!</source>
-        <translation type="unfinished"></translation>
+        <translation>¡No es posible eliminar la lista, error de eliminación de audios!</translation>
+    </message>
+    <message>
+        <source>RDLogEdit -- Database Skew</source>
+        <translation>RDLogEdit -- Asimetría en la Base de Datos</translation>
+    </message>
+    <message>
+        <source>This version of RDLogEdit is incompatible with the version installed on the server.
+See your system administrator for an update!</source>
+        <translation>Esta versión de RDLogEdit es incompatible con la versión instalada en el servidor.
+¡Solicite una actualización al administrador!</translation>
+    </message>
+</context>
+<context>
+    <name>VoiceTracker</name>
+    <message>
+        <source>Voice Tracker</source>
+        <translation>Pista de voz</translation>
+    </message>
+    <message>
+        <source>Edit Cue Markers</source>
+        <translation>Editar marcadores</translation>
+    </message>
+    <message>
+        <source>Undo Segue Changes</source>
+        <translation>Deshacer cambios en Segue</translation>
+    </message>
+    <message>
+        <source>Set Start Point Here</source>
+        <translation>Colocar punto de inicio aquí</translation>
+    </message>
+    <message>
+        <source>Set End Point Here</source>
+        <translation>Colocar punto de fin aquí</translation>
+    </message>
+    <message>
+        <source>Set to Hook Markers</source>
+        <translation>Colocar en los marcadores &quot;Hook&quot;</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Inicio</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>Grabar</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Guardar</translation>
+    </message>
+    <message>
+        <source>&amp;Previous
+Track</source>
+        <translation>Pista 
+&amp;Anterior</translation>
+    </message>
+    <message>
+        <source>&amp;Next
+Track</source>
+        <translation>Pista
+&amp;Siguiente</translation>
+    </message>
+    <message>
+        <source>Remaining</source>
+        <translation>Restan</translation>
+    </message>
+    <message>
+        <source>Tracks</source>
+        <translation>Pistas</translation>
+    </message>
+    <message>
+        <source>Time</source>
+        <translation>Tiempo</translation>
+    </message>
+    <message>
+        <source> </source>
+        <translation> </translation>
+    </message>
+    <message>
+        <source>TIME</source>
+        <translation>TIEMPO</translation>
+    </message>
+    <message>
+        <source>TRANS</source>
+        <translation>TRANS</translation>
+    </message>
+    <message>
+        <source>CART</source>
+        <translation>CARTUCHO</translation>
+    </message>
+    <message>
+        <source>GROUP</source>
+        <translation>GRUPO</translation>
+    </message>
+    <message>
+        <source>LENGTH</source>
+        <translation>DURACIÓN</translation>
+    </message>
+    <message>
+        <source>TITLE</source>
+        <translation>TÍTULO</translation>
+    </message>
+    <message>
+        <source>ARTIST</source>
+        <translation>ARTISTA</translation>
+    </message>
+    <message>
+        <source>Do Over</source>
+        <translation>Sobre-
+escribir</translation>
+    </message>
+    <message>
+        <source>Hit Post</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Insert
+Track</source>
+        <translation>Insertar
+Pista</translation>
+    </message>
+    <message>
+        <source>Delete
+Track</source>
+        <translation>Borrar
+Pista</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation>&amp;Cerrar</translation>
+    </message>
+    <message>
+        <source>No VoiceTrack Group</source>
+        <translation>No hay grupos para las pistas de voz</translation>
+    </message>
+    <message>
+        <source>No voicetracking group has been defined for this service,
+therefore only existing transitions will be editable.</source>
+        <translation>No se ha definido un grupo para las pistas de voz, por ende
+sólo podrás editar transiciones ya existentes.</translation>
+    </message>
+    <message>
+        <source>Import</source>
+        <translation>Importar</translation>
+    </message>
+    <message>
+        <source>Cart Creation Failure</source>
+        <translation>Falló la creación de cartuchos</translation>
+    </message>
+    <message>
+        <source>Unable to create new cart for voice track!</source>
+        <translation>¡No fue posible crear un nuevo cartucho para la pista de voz!</translation>
+    </message>
+    <message>
+        <source>RDLogEdit</source>
+        <translation>RDLogEdit</translation>
+    </message>
+    <message>
+        <source>Audio Deletion Error!</source>
+        <translation>¡Error eliminando audio!</translation>
+    </message>
+    <message>
+        <source>TRACK</source>
+        <translation>PISTA</translation>
+    </message>
+    <message>
+        <source>Voice Track</source>
+        <translation>Pista de voz</translation>
+    </message>
+    <message>
+        <source>Track List</source>
+        <translation>Listado de pistas</translation>
+    </message>
+    <message>
+        <source>No more tracks!</source>
+        <translation>¡No hay más pistas!</translation>
+    </message>
+    <message>
+        <source>[end of log]</source>
+        <translation>[fin de la lista]</translation>
+    </message>
+    <message>
+        <source>[cart not found]</source>
+        <translation>[cartucho no encontrado]</translation>
+    </message>
+    <message>
+        <source>MARKER</source>
+        <translation>MARCADOR</translation>
+    </message>
+    <message>
+        <source>LOG CHAIN</source>
+        <translation>ENCADENAR A LISTA</translation>
+    </message>
+    <message>
+        <source>LINK</source>
+        <translation>ENLACE</translation>
+    </message>
+    <message>
+        <source>[music import]</source>
+        <translation>[importar música]</translation>
+    </message>
+    <message>
+        <source>[traffic import]</source>
+        <translation>[importar tráfico]</translation>
+    </message>
+    <message>
+        <source>PLAY</source>
+        <translation>REPROD</translation>
+    </message>
+    <message>
+        <source>SEGUE</source>
+        <translation>SEGUE</translation>
+    </message>
+    <message>
+        <source>STOP</source>
+        <translation>PARAR</translation>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation>Abortar</translation>
+    </message>
+    <message>
+        <source>Segue Changed</source>
+        <translation>Segue modificado</translation>
+    </message>
+    <message>
+        <source>Save segue changes?</source>
+        <translation>¿Guardar cambios en Segue?</translation>
     </message>
 </context>
 </TS>
