@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004,2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_event.cpp,v 1.44.2.7 2009/06/29 13:15:37 cvs Exp $
+//      $Id: edit_event.cpp,v 1.53 2012/02/20 16:44:53 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -384,7 +384,7 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   //
   // Pre-Import Carts Section
   //
-  label=new QLabel("PRE-IMPORT CARTS",this,"preimport_carts_label");
+  label=new QLabel(tr("PRE-IMPORT CARTS"),this,"preimport_carts_label");
   label->setFont(bold_font);
   label->setGeometry(CENTER_LINE+15,210,200,16);
 
@@ -440,7 +440,7 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   //
   // Import Section
   //
-  label=new QLabel("IMPORT",this,"preimport_carts_label");
+  label=new QLabel(tr("IMPORT"),this,"preimport_carts_label");
   label->setFont(bold_font);
   label->setGeometry(CENTER_LINE+15,362,200,16);
   
@@ -1304,11 +1304,11 @@ void EditEvent::RefreshLibrary()
 
   switch(event_lib_type_group->selectedId()) {
       case 0:
-	type_filter="((TYPE=1)||(TYPE=2))";
+	type_filter="((TYPE=1)||(TYPE=2)||(TYPE=3))";
 	break;
 
       case 1:
-	type_filter="(TYPE=1)";
+	type_filter="((TYPE=1)||(TYPE=3))";
 	break;
 
       case 2:
@@ -1318,13 +1318,13 @@ void EditEvent::RefreshLibrary()
   QString sql="select TYPE,NUMBER,GROUP_NAME,FORCED_LENGTH,TITLE,ARTIST,\
                START_DATETIME,END_DATETIME from CART";
   QString group=event_group_box->currentText();
-  if(group==QString("ALL")) {
+  if(group==QString(tr("ALL"))) {
     group="";
   }
   sql+=QString().
     sprintf(" where %s && %s",
 	    (const char *)
-	    RDCartSearchText(event_lib_filter_edit->text(),group).utf8(),
+	    RDCartSearchText(event_lib_filter_edit->text(),group,"").utf8(),
 	    (const char *)type_filter);
   RDSqlQuery *q=new RDSqlQuery(sql);
   QListViewItem *item;
@@ -1342,7 +1342,7 @@ void EditEvent::RefreshLibrary()
 	  item->setText(8,tr("Macro"));
 	  break;
 
-	default:
+    case RDCart::All:
 	  break;
     }
     item->setText(1,QString().sprintf("%06u",q->value(1).toInt()));
