@@ -2,9 +2,9 @@
 //
 // Rivendell Interprocess Communication Daemon
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2007,2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: ripcd.cpp,v 1.64.2.5 2009/02/10 13:41:35 cvs Exp $
+//      $Id: ripcd.cpp,v 1.77 2011/06/21 22:20:44 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -46,6 +46,7 @@
 #include <rdcheck_daemons.h>
 #include <rdcmd_switch.h>
 #include <rddb.h>
+#include <dbversion.h>
 
 #include <globals.h>
 #include <ripcd_socket.h>
@@ -92,11 +93,18 @@ void SigHandler(int signo)
 MainObject::MainObject(QObject *parent,const char *name)
   :QObject(parent,name)
 {
+  bool skip_db_check=false;
+
   //
   // Read Command Options
   //
   RDCmdSwitch *cmd=
     new RDCmdSwitch(qApp->argc(),qApp->argv(),"ripcd",RIPCD_USAGE);
+  for(unsigned i=0;i<cmd->keys();i++) {
+    if(cmd->key(i)=="--skip-db-check") {
+      skip_db_check=true;
+    }
+  }
   delete cmd;
 
   //
@@ -118,14 +126,8 @@ MainObject::MainObject(QObject *parent,const char *name)
   // Initialize Data Structures
   //
   debug=false;
-  for(int i=0;i<RIPCD_MAX_CONNECTIONS;i++) {
-    socket[i]=NULL;
-    istate[i]=0;
-    argnum[i]=0;
-    argptr[i]=0;
-    auth[i]=false;
-  }
   for(int i=0;i<MAX_MATRICES;i++) {
+    ripcd_switcher[i]=NULL;
     for(int j=0;j<MAX_GPIO_PINS;j++) {
       ripcd_gpi_state[i][j]=false;
       ripcd_gpo_state[i][j]=false;
@@ -154,22 +156,21 @@ MainObject::MainObject(QObject *parent,const char *name)
   //
   // Open Database
   //
-
+  unsigned schema=0;
   QString err (tr("ripcd: "));
-  ripcd_db = RDInitDb (&err);
+  ripcd_db = RDInitDb (&schema,&err);
   if(!ripcd_db) {
     printf ("%s\n",err.ascii());
     exit (1);
   }
+  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
+    fprintf(stderr,"database version mismatch, should be %u, is %u",
+	    RD_VERSION_DATABASE,schema);
+    exit(256);
+  }
   connect (RDDbStatus(),SIGNAL(logText(RDConfig::LogPriority,const QString &)),
 	   this,SLOT(log(RDConfig::LogPriority,const QString &)));
 
-  //
-  // CAE Connection
-  //
-  rdcae=new RDCae(parent,name);
-  rdcae->connectHost("localhost",CAED_TCP_PORT,ripcd_config->password());
-
   //
   // Station 
   //
@@ -177,6 +178,12 @@ MainObject::MainObject(QObject *parent,const char *name)
   rdstation->setUserName(rdstation->defaultName());
   ripcd_host_addr=rdstation->address();
 
+  //
+  // CAE Connection
+  //
+  rdcae=new RDCae(rdstation,ripcd_config,parent,name);
+  rdcae->connectHost();
+
   if(qApp->argc()==1) {
     RDDetach(ripcd_config->logCoreDumpDirectory());
   }
@@ -258,19 +265,20 @@ void MainObject::log(RDConfig::LogPriority prio,const QString &msg)
 
 void MainObject::newConnection(int fd)
 {
-  int i=0;
+  unsigned i=0;
 
-  while((i<RIPCD_MAX_CONNECTIONS)&&(socket[i]!=NULL)) {
+  while((i<ripcd_conns.size())&&(ripcd_conns[i]!=NULL)) {
     i++;
   }
-  if(i==RIPCD_MAX_CONNECTIONS) {      // Table full, drop it on the floor
-    close(fd);
-    return;
+  if(i==ripcd_conns.size()) {      // Table full, create a new slot
+    ripcd_conns.push_back(new RipcdConnection(i,fd));
   }
-  socket[i]=new RDSocket(i,this,"socket_0");
-  socket[i]->setSocket(fd);
-  connect(socket[i],SIGNAL(readyReadID(int)),this,SLOT(socketData(int)));
-  connect(socket[i],SIGNAL(connectionClosedID(int)),
+  else {
+    ripcd_conns[i]=new RipcdConnection(i,fd);
+  }
+  connect(ripcd_conns[i]->socket,SIGNAL(readyReadID(int)),
+	  this,SLOT(socketData(int)));
+  connect(ripcd_conns[i]->socket,SIGNAL(connectionClosedID(int)),
 	  this,SLOT(socketKill(int)));
 }
 
@@ -286,12 +294,7 @@ void MainObject::sendRml(RDMacro *rml)
   buf[n]=0;
   switch(rml->role()) {
       case RDMacro::Cmd:
-	if(rml->echoRequested()) {
-	  ripcd_rml_send->writeBlock(buf,n,rml->address(),RD_RML_ECHO_PORT);
-	}
-	else {
-	  ripcd_rml_send->writeBlock(buf,n,rml->address(),RD_RML_NOECHO_PORT);
-	}
+	ripcd_rml_send->writeBlock(buf,n,rml->address(),rml->port());
 	break;
 
       case RDMacro::Reply:
@@ -414,15 +417,16 @@ void MainObject::ParseCommand(int ch)
 {
   char buf[256];
   int c;
+  RipcdConnection *conn=ripcd_conns[ch];
 
-  while((c=socket[ch]->readBlock(buf,256))>0) {
+  while((c=conn->socket->readBlock(buf,256))>0) {
     buf[c]=0;
     for(int i=0;i<c;i++) {
       if(buf[i]==' ') {
-	if(argnum[ch]<RD_RML_MAX_ARGS) {
-	  args[ch][argnum[ch]][argptr[ch]]=0;
-	  argnum[ch]++;
-	  argptr[ch]=0;
+	if(conn->argnum<RD_RML_MAX_ARGS) {
+	  conn->args[conn->argnum][conn->argptr]=0;
+	  conn->argnum++;
+	  conn->argptr=0;
 	}
 	else {
 	  LogLine(RDConfig::LogWarning,QString().
@@ -430,18 +434,18 @@ void MainObject::ParseCommand(int ch)
 	}
       }
       if(buf[i]=='!') {
-	args[ch][argnum[ch]++][argptr[ch]]=0;
+	conn->args[conn->argnum++][conn->argptr]=0;
 	DispatchCommand(ch);
-	argnum[ch]=0;
-	argptr[ch]=0;
-	if(socket[ch]==NULL) {
+	conn->argnum=0;
+	conn->argptr=0;
+	if(conn->socket==NULL) {
 	  return;
 	}
       }
       if((isgraph(buf[i]))&&(buf[i]!='!')) {
-	if(argptr[ch]<RIPCD_MAX_LENGTH) {
-	  args[ch][argnum[ch]][argptr[ch]]=buf[i];
-	  argptr[ch]++;
+	if(conn->argptr<RIPCD_MAX_LENGTH) {
+	  conn->args[conn->argnum][conn->argptr]=buf[i];
+	  conn->argptr++;
 	}
 	else {
 	  if(debug) {
@@ -464,24 +468,26 @@ void MainObject::DispatchCommand(int ch)
   char cmd[RD_RML_MAX_LENGTH+4];
   int echo=0;
   QHostAddress addr;
+  RipcdConnection *conn=ripcd_conns[ch];
+  unsigned port;
 
   //
   // Common Commands
   // Authentication not required to execute these!
   //
-  if(!strcmp(args[ch][0],"DC")) {  // Drop Connection
-    socket[ch]->close();
+  if(!strcmp(conn->args[0],"DC")) {  // Drop Connection
+    conn->socket->close();
     KillSocket(ch);
     return;
   }
-  if(!strcmp(args[ch][0],"PW")) {  // Password Authenticate
-    if(!strcmp(args[ch][1],ripcd_config->password())) {
-      auth[ch]=true;
+  if(!strcmp(conn->args[0],"PW")) {  // Password Authenticate
+    if(!strcmp(conn->args[1],ripcd_config->password())) {
+      conn->auth=true;
       EchoCommand(ch,"PW +!");
       return;
     }
     else {
-      auth[ch]=false;
+      conn->auth=false;
       EchoCommand(ch,"PW -!");
       return;
     }
@@ -491,35 +497,37 @@ void MainObject::DispatchCommand(int ch)
   // Priviledged Commands
   // Authentication required to execute these!
   //
-  if(!auth[ch]) {
+  if(!conn->auth) {
     EchoArgs(ch,'-');
     return;
   }
 
-  if(!strcmp(args[ch][0],"RU")) {  // Request User
+  if(!strcmp(conn->args[0],"RU")) {  // Request User
     EchoCommand(ch,(const char *)QString().
 		sprintf("RU %s!",(const char *)rdstation->userName()));
     return;
   }
 
-  if(!strcmp(args[ch][0],"SU")) {  // Set User
-    SetUser(args[ch][1]);
+  if(!strcmp(conn->args[0],"SU")) {  // Set User
+    SetUser(conn->args[1]);
   }
 
-  if(!strcmp(args[ch][0],"MS")) {  // Send RML Command
-    if(argnum[ch]<4) {
+  if(!strcmp(conn->args[0],"MS")) {  // Send RML Command
+    if(conn->argnum<4) {
       return;
     }
-    strcpy(str,args[ch][3]);
-    for(int i=4;i<argnum[ch];i++) {
+    strcpy(str,conn->args[3]);
+    for(int i=4;i<conn->argnum;i++) {
       strcat(str," ");
-      strcat(str,args[ch][i]);
+      strcat(str,conn->args[i]);
     }
     strcat(str,"!");
   }
   if(macro.parseString(str,strlen(str))) {
-    addr.setAddress(args[ch][1]);
+    addr.setAddress(conn->args[1]);
     macro.setAddress(addr);
+    sscanf(conn->args[2],"%u",&port);
+    macro.setPort(port);
     macro.setRole(RDMacro::Cmd);
 
 /*
@@ -529,7 +537,9 @@ void MainObject::DispatchCommand(int ch)
 */
 
     if(!macro.address().isNull()) {
-      if(macro.address()==rdstation->address()) {  // Local Loopback
+      if(macro.address()==rdstation->address()&&
+	 ((macro.port()==RD_RML_ECHO_PORT)||
+	  (macro.port()==RD_RML_NOECHO_PORT))) {  // Local Loopback
 	macro.generateString(buffer,RD_RML_MAX_LENGTH);
 	if(macro.echoRequested()) {
 	  echo=1;
@@ -545,20 +555,20 @@ void MainObject::DispatchCommand(int ch)
     }
   }
 
-  if(!strcmp(args[ch][0],"ME")) {  // Send RML Reply
-    if(argnum[ch]<4) {
+  if(!strcmp(conn->args[0],"ME")) {  // Send RML Reply
+    if(conn->argnum<4) {
       return;
     }
-    strcpy(str,args[ch][3]);
-    for(int i=4;i<argnum[ch];i++) {
+    strcpy(str,conn->args[3]);
+    for(int i=4;i<conn->argnum;i++) {
       strcat(str," ");
-      strcat(str,args[ch][i]);
+      strcat(str,conn->args[i]);
     }
     strcat(str,"!");
   }
   if(macro.parseString(str,strlen(str))) {
     QHostAddress addr;
-    addr.setAddress(args[ch][1]);
+    addr.setAddress(conn->args[1]);
     macro.setAddress(addr);
     macro.setRole(RDMacro::Reply); 
     if(macro.address()==rdstation->address()) {  // Local Loopback
@@ -572,47 +582,47 @@ void MainObject::DispatchCommand(int ch)
     }
   }
 
-  if(!strcmp(args[ch][0],"RG")) {  // Reload the GPI Table
+  if(!strcmp(conn->args[0],"RG")) {  // Reload the GPI Table
     LoadGpiTable();
   }
 
-  if(!strcmp(args[ch][0],"GI")) {  // Send Complete GPI Status
+  if(!strcmp(conn->args[0],"GI")) {  // Send Complete GPI Status
     int matrix;
-    sscanf(args[ch][1],"%d",&matrix);
+    sscanf(conn->args[1],"%d",&matrix);
     SendGpi(ch,matrix);
   }
 
-  if(!strcmp(args[ch][0],"GO")) {  // Send Complete GPO Status
+  if(!strcmp(conn->args[0],"GO")) {  // Send Complete GPO Status
     int matrix;
-    sscanf(args[ch][1],"%d",&matrix);
+    sscanf(conn->args[1],"%d",&matrix);
     SendGpo(ch,matrix);
   }
 
-  if(!strcmp(args[ch][0],"GM")) {  // Send Complete GPI Mask States
+  if(!strcmp(conn->args[0],"GM")) {  // Send Complete GPI Mask States
     int matrix;
-    sscanf(args[ch][1],"%d",&matrix);
+    sscanf(conn->args[1],"%d",&matrix);
     SendGpiMask(ch,matrix);
   }
 
-  if(!strcmp(args[ch][0],"GN")) {  // Send Complete GPI Mask States
+  if(!strcmp(conn->args[0],"GN")) {  // Send Complete GPI Mask States
     int matrix;
-    sscanf(args[ch][1],"%d",&matrix);
+    sscanf(conn->args[1],"%d",&matrix);
     SendGpoMask(ch,matrix);
   }
 
-  if(!strcmp(args[ch][0],"GC")) {  // Send Complete GPI Cart Assignments
+  if(!strcmp(conn->args[0],"GC")) {  // Send Complete GPI Cart Assignments
     int matrix;
-    sscanf(args[ch][1],"%d",&matrix);
+    sscanf(conn->args[1],"%d",&matrix);
     SendGpiCart(ch,matrix);
   }
 
-  if(!strcmp(args[ch][0],"GD")) {  // Send Complete GPO Cart Assignments
+  if(!strcmp(conn->args[0],"GD")) {  // Send Complete GPO Cart Assignments
     int matrix;
-    sscanf(args[ch][1],"%d",&matrix);
+    sscanf(conn->args[1],"%d",&matrix);
     SendGpoCart(ch,matrix);
   }
 
-  if(!strcmp(args[ch][0],"TA")) {  // Send Onair Flag State
+  if(!strcmp(conn->args[0],"TA")) {  // Send Onair Flag State
     EchoCommand(ch,QString().sprintf("TA %d!",ripc_onair_flag));
   }
 }
@@ -620,28 +630,23 @@ void MainObject::DispatchCommand(int ch)
 
 void MainObject::KillSocket(int ch)
 {
-  istate[ch]=0;
-  argnum[ch]=0;
-  argptr[ch]=0;
-  auth[ch]=false;
-
-  delete socket[ch];
-  socket[ch]=NULL;
+  delete ripcd_conns[ch];
+  ripcd_conns[ch]=NULL;
 }
 
 
 void MainObject::EchoCommand(int ch,const char *command)
 {
-  if(socket[ch]->state()==QSocket::Connection) {
-    socket[ch]->writeBlock(command,strlen(command));
+  if(ripcd_conns[ch]->socket->state()==QSocket::Connection) {
+    ripcd_conns[ch]->socket->writeBlock(command,strlen(command));
   }
 }
 
 
 void MainObject::BroadcastCommand(const char *command)
 {
-  for(int i=0;i<RIPCD_MAX_CONNECTIONS;i++) {
-    if(socket[i]!=NULL) {
+  for(unsigned i=0;i<ripcd_conns.size();i++) {
+    if(ripcd_conns[i]!=NULL) {
       EchoCommand(i,command);
     }
   }
@@ -654,8 +659,8 @@ void MainObject::EchoArgs(int ch,const char append)
   int l;
 
   command[0]=0;
-  for(int i=0;i<argnum[ch];i++) {
-    strcat(command,args[ch][i]);
+  for(int i=0;i<ripcd_conns[ch]->argnum;i++) {
+    strcat(command,ripcd_conns[ch]->args[i]);
     strcat(command," ");
   }
   l=strlen(command);
@@ -760,13 +765,16 @@ void MainObject::LoadGpiTable()
 
 void MainObject::SendGpi(int ch,int matrix)
 {
-  switch(ripcd_matrix_type[matrix]) {
+  if(ripcd_switcher[matrix]==NULL) {
+    return;
+  }
+  switch(ripcd_switcher[matrix]->type()) {
     case RDMatrix::LiveWire:
-      ripcd_livewire[matrix]->sendGpi();
+      ripcd_switcher[matrix]->sendGpi();
       break;
 
     default:
-      for(int i=0;i<ripcd_gpis[matrix];i++) {
+      for(unsigned i=0;i<ripcd_switcher[matrix]->gpiQuantity();i++) {
 	EchoCommand(ch,QString().sprintf("GI %d %d %d %d!",
 					 matrix,i,ripcd_gpi_state[matrix][i],
 					 ripcd_gpi_mask[matrix][i]));
@@ -778,13 +786,16 @@ void MainObject::SendGpi(int ch,int matrix)
 
 void MainObject::SendGpo(int ch,int matrix)
 {
-  switch(ripcd_matrix_type[matrix]) {
+  if(ripcd_switcher[matrix]==NULL) {
+    return;
+  }
+  switch(ripcd_switcher[matrix]->type()) {
     case RDMatrix::LiveWire:
-      ripcd_livewire[matrix]->sendGpo();
+      ripcd_switcher[matrix]->sendGpo();
       break;
 
     default:
-      for(int i=0;i<ripcd_gpos[matrix];i++) {
+      for(unsigned i=0;i<ripcd_switcher[matrix]->gpoQuantity();i++) {
 	EchoCommand(ch,QString().sprintf("GO %d %d %d %d!",
 					 matrix,i,ripcd_gpo_state[matrix][i],
 					 ripcd_gpo_mask[matrix][i]));
@@ -796,7 +807,10 @@ void MainObject::SendGpo(int ch,int matrix)
 
 void MainObject::SendGpiMask(int ch,int matrix)
 {
-  for(int i=0;i<ripcd_gpis[matrix];i++) {
+  if(ripcd_switcher[matrix]==NULL) {
+    return;
+  }
+  for(unsigned i=0;i<ripcd_switcher[matrix]->gpiQuantity();i++) {
     EchoCommand(ch,QString().sprintf("GM %d %d %d!",
 				     matrix,i,ripcd_gpi_mask[matrix][i]));
   }
@@ -805,7 +819,10 @@ void MainObject::SendGpiMask(int ch,int matrix)
 
 void MainObject::SendGpoMask(int ch,int matrix)
 {
-  for(int i=0;i<ripcd_gpos[matrix];i++) {
+  if(ripcd_switcher[matrix]==NULL) {
+    return;
+  }
+  for(unsigned i=0;i<ripcd_switcher[matrix]->gpoQuantity();i++) {
     EchoCommand(ch,QString().sprintf("GN %d %d %d!",
 				     matrix,i,ripcd_gpo_mask[matrix][i]));
   }
@@ -814,7 +831,10 @@ void MainObject::SendGpoMask(int ch,int matrix)
 
 void MainObject::SendGpiCart(int ch,int matrix)
 {
-  for(int i=0;i<ripcd_gpis[matrix];i++) {
+  if(ripcd_switcher[matrix]==NULL) {
+    return;
+  }
+  for(unsigned i=0;i<ripcd_switcher[matrix]->gpiQuantity();i++) {
     EchoCommand(ch,QString().sprintf("GC %d %d %d %d!",
 				     matrix,i,ripcd_gpi_macro[matrix][i][0],
 				     ripcd_gpi_macro[matrix][i][1]));
@@ -824,7 +844,10 @@ void MainObject::SendGpiCart(int ch,int matrix)
 
 void MainObject::SendGpoCart(int ch,int matrix)
 {
-  for(int i=0;i<ripcd_gpos[matrix];i++) {
+  if(ripcd_switcher[matrix]==NULL) {
+    return;
+  }
+  for(unsigned i=0;i<ripcd_switcher[matrix]->gpoQuantity();i++) {
     EchoCommand(ch,QString().sprintf("GD %d %d %d %d!",
 				     matrix,i,ripcd_gpo_macro[matrix][i][0],
 				     ripcd_gpo_macro[matrix][i][1]));
